b=('kkwem','kkweb','kkwebs','kkwes','kkwess','kkweng','kkwej','kkwech','kkwek','kkwet','kkwep','kkweh','kkwi','kkwig','kkwikk','kkwigs','kkwin','kkwinj','kkwinh','kkwid','kkwil','kkwilg','kkwilm','kkwilb','kkwils','kkwilt','kkwilp','kkwilh','kkwim','kkwib','kkwibs','kkwis','kkwiss','kkwing','kkwij','kkwich','kkwik','kkwit','kkwip','kkwih','kkyu','kkyug','kkyukk','kkyugs','kkyun','kkyunj','kkyunh','kkyud','kkyul','kkyulg','kkyulm','kkyulb','kkyuls','kkyult','kkyulp','kkyulh','kkyum','kkyub','kkyubs','kkyus','kkyuss','kkyung','kkyuj','kkyuch','kkyuk','kkyut','kkyup','kkyuh','kkeu','kkeug','kkeukk','kkeugs','kkeun','kkeunj','kkeunh','kkeud','kkeul','kkeulg','kkeulm','kkeulb','kkeuls','kkeult','kkeulp','kkeulh','kkeum','kkeub','kkeubs','kkeus','kkeuss','kkeung','kkeuj','kkeuch','kkeuk','kkeut','kkeup','kkeuh','kkui','kkuig','kkuikk','kkuigs','kkuin','kkuinj','kkuinh','kkuid','kkuil','kkuilg','kkuilm','kkuilb','kkuils','kkuilt','kkuilp','kkuilh','kkuim','kkuib','kkuibs','kkuis','kkuiss','kkuing','kkuij','kkuich','kkuik','kkuit','kkuip','kkuih','kki','kkig','kkikk','kkigs','kkin','kkinj','kkinh','kkid','kkil','kkilg','kkilm','kkilb','kkils','kkilt','kkilp','kkilh','kkim','kkib','kkibs','kkis','kkiss','kking','kkij','kkich','kkik','kkit','kkip','kkih','na','nag','nakk','nags','nan','nanj','nanh','nad','nal','nalg','nalm','nalb','nals','nalt','nalp','nalh','nam','nab','nabs','nas','nass','nang','naj','nach','nak','nat','nap','nah','nae','naeg','naekk','naegs','naen','naenj','naenh','naed','nael','naelg','naelm','naelb','naels','naelt','naelp','naelh','naem','naeb','naebs','naes','naess','naeng','naej','naech','naek','naet','naep','naeh','nya','nyag','nyakk','nyags','nyan','nyanj','nyanh','nyad','nyal','nyalg','nyalm','nyalb','nyals','nyalt','nyalp','nyalh','nyam','nyab','nyabs','nyas','nyass','nyang','nyaj','nyach','nyak','nyat','nyap','nyah','nyae','nyaeg','nyaekk','nyaegs','nyaen','nyaenj','nyaenh','nyaed','nyael','nyaelg','nyaelm','nyaelb','nyaels','nyaelt','nyaelp','nyaelh','nyaem','nyaeb','nyaebs','nyaes')


b=('Xi','Gao','Lang','Fu','Xun','Shui','Lu','Kun','Gan','Jing','Ti','Cheng','Tu','Shao','Shui','Ya','Lun','Lu','Gu','Zuo','Ren','Zhun','Bang','Bai','Ji','Zhi','Zhi','Kun','Leng','Peng','Ke','Bing','Chou','Zui','Yu','Su','Lue','Xiang','Yi','Xi','Bian','Ji','Fu','Pi','Nuo','Jie','Zhong','Zong','Xu','Cheng','Dao','Wen','Xian','Zi','Yu','Ji','Xu','Zhen','Zhi','Dao','Jia','Ji','Gao','Gao','Gu','Rong','Sui','Rong','Ji','Kang','Mu','Can','Mei','Zhi','Ji','Lu','Su','Ji','Ying','Wen','Qiu','Se','He','Yi','Huang','Qie','Ji','Sui','Xiao','Pu','Jiao','Zhuo','Zhong','Zui','Lu','Sui','Nong','Se','Hui','Rang','Nuo','Yu','Pin','Ji','Tui','Wen','Cheng','Huo','Kuang','Lu','Biao','Se','Rang','Zhuo','Li','Cuan','Xue','Wa','Jiu','Qiong','Xi','Qiong','Kong','Yu','Shen','Jing','Yao','Chuan','Zhun','Tu','Lao','Qie','Zhai','Yao','Bian','Bao','Yao','Bing','Wa','Zhu','Jiao','Qiao','Diao','Wu','Gui','Yao','Zhi','Chuang','Yao','Tiao','Jiao','Chuang','Jiong','Xiao','Cheng','Kou','Cuan','Wo','Dan','Ku','Ke','Zhuo','Xu','Su','Guan','Kui','Dou','Zhuo','Xun','Wo','Wa','Ya','Yu','Ju','Qiong','Yao','Yao','Tiao','Chao','Yu','Tian','Diao','Ju','Liao','Xi','Wu','Kui','Chuang','Zhao','Kuan','Kuan','Long','Cheng','Cui','Liao','Zao','Cuan','Qiao','Qiong','Dou','Zao','Long','Qie','Li','Chu','Shi','Fu','Qian','Chu','Hong','Qi','Hao','Sheng','Fen','Shu','Miao','Qu','Zhan','Zhu','Ling','Long','Bing','Jing','Jing','Zhang','Bai','Si','Jun','Hong','Tong','Song','Jing','Diao','Yi','Shu','Jing','Qu','Jie','Ping','Duan','Li','Zhuan','Ceng','Deng','Cun','Wai','Jing','Kan','Jing','Zhu','Zhu','Le','Peng','Yu','Chi','Gan')


b=('nzup','nzurx','nzur','nzyt','nzyx','nzy','nzyp','nzyrx','nzyr','sit','six','si','sip','siex','sie','siep','sat','sax','sa','sap','suox','suo','suop','sot','sox','so','sop','sex','se','sep','sut','sux','su','sup','surx','sur','syt','syx','sy','syp','syrx','syr','ssit','ssix','ssi','ssip','ssiex','ssie','ssiep','ssat','ssax','ssa','ssap','ssot','ssox','sso','ssop','ssex','sse','ssep','ssut','ssux','ssu','ssup','ssyt','ssyx','ssy','ssyp','ssyrx','ssyr','zhat','zhax','zha','zhap','zhuox','zhuo','zhuop','zhot','zhox','zho','zhop','zhet','zhex','zhe','zhep','zhut','zhux','zhu','zhup','zhurx','zhur','zhyt','zhyx','zhy','zhyp','zhyrx','zhyr','chat','chax','cha','chap','chuot','chuox','chuo','chuop','chot','chox','cho','chop','chet','chex','che','chep','chux','chu','chup','churx','chur','chyt','chyx','chy','chyp','chyrx','chyr','rrax','rra','rruox','rruo','rrot','rrox','rro','rrop','rret','rrex','rre','rrep','rrut','rrux','rru','rrup','rrurx','rrur','rryt','rryx','rry','rryp','rryrx','rryr','nrat','nrax','nra','nrap','nrox','nro','nrop','nret','nrex','nre','nrep','nrut','nrux','nru','nrup','nrurx','nrur','nryt','nryx','nry','nryp','nryrx','nryr','shat','shax','sha','shap','shuox','shuo','shuop','shot','shox','sho','shop','shet','shex','she','shep','shut','shux','shu','shup','shurx','shur','shyt','shyx','shy','shyp','shyrx','shyr','rat','rax','ra','rap','ruox','ruo','ruop','rot','rox','ro','rop','rex','re','rep','rut','rux','ru','rup','rurx','rur','ryt','ryx','ry','ryp','ryrx','ryr','jit','jix','ji','jip','jiet','jiex','jie','jiep','juot','juox','juo','juop','jot','jox','jo','jop','jut','jux','ju','jup','jurx','jur','jyt','jyx','jy','jyp','jyrx','jyr','qit','qix','qi','qip')


b=('Chan','Ge','Lou','Zong','Gen','Jiao','Gou','Qin','Rong','Que','Chou','Chuai','Zhan','Sun','Sun','Bo','Chu','Rong','Bang','Cuo','Sao','Ke','Yao','Dao','Zhi','Nu','La','Jian','Sou','Qiu','Gao','Xian','Shuo','Sang','Jin','Mie','E','Chui','Nuo','Shan','Ta','Zha','Tang','Pan','Ban','Da','Li','Tao','Hu','Zhi','Wa','Hua','Qian','Wen','Qiang','Tian','Zhen','E','Xie','Nuo','Quan','Cha','Zha','Ge','Wu','En','She','Kang','She','Shu','Bai','Yao','Bin','Sou','Tan','Sa','Chan','Suo','Jiu','Chong','Chuang','Guai','Bing','Feng','Shuai','Di','Qi','Sou','Zhai','Lian','Cheng','Chi','Guan','Lu','Luo','Lou','Zong','Gai','Hu','Zha','Chuang','Tang','Hua','Cui','Nai','Mo','Jiang','Gui','Ying','Zhi','Ao','Zhi','Nie','Man','Chan','Kou','Chu','She','Tuan','Jiao','Mo','Mo','Zhe','Can','Keng','Biao','Jiang','Yao','Gou','Qian','Liao','Ji','Ying','Jue','Pie','Pie','Lao','Dun','Xian','Ruan','Gui','Zan','Yi','Xian','Cheng','Cheng','Sa','Nao','Hong','Si','Han','Guang','Da','Zun','Nian','Lin','Zheng','Hui','Zhuang','Jiao','Ji','Cao','Dan','Dan','Che','Bo','Che','Jue','Fu','Liao','Ben','Fu','Qiao','Bo','Cuo','Zhuo','Zhuan','Wei','Pu','Qin','Dun','Nian','Hua','Xie','Lu','Jiao','Cuan','Ta','Han','Qiao','Wo','Jian','Gan','Yong','Lei','Nang','Lu','Shan','Zhuo','Ze','Pu','Chuo','Ji','Dang','Se','Cao','Qing','Qing','Huan','Jie','Qin','Kuai','Dan','Xie','Ka','Pi','Bai','Ao','Ju','Ye','E','Meng','Sou','Mi','Ji','Tai','Zhuo','Dao','Xing','Lan','Ca','Ju','Ye','Ru','Ye','Ye','Ni','Wo','Jie','Bin','Ning','Ge','Zhi','Zhi','Kuo','Mo','Jian','Xie','Lie','Tan','Bai','Sou','Lu','Lue','Rao','Ti')


b=('Ci','Xiang','She','Luo','Qin','Ying','Chai','Li','Zei','Xuan','Lian','Zhu','Ze','Xie','Mang','Xie','Qi','Rong','Jian','Meng','Hao','Ru','Huo','Zhuo','Jie','Pin','He','Mie','Fan','Lei','Jie','La','Min','Li','Chun','Li','Qiu','Nie','Lu','Du','Xiao','Zhu','Long','Li','Long','Feng','Ye','Pi','Nang','Gu','Juan','Ying','Shu','Xi','Can','Qu','Quan','Du','Can','Man','Qu','Jie','Zhu','Zhuo','Xue','Huang','Nu','Pei','Nu','Xin','Zhong','Mai','Er','Ka','Mie','Xi','Xing','Yan','Kan','Yuan','Qu','Ling','Xuan','Shu','Xian','Tong','Xiang','Jie','Xian','Ya','Hu','Wei','Dao','Chong','Wei','Dao','Zhun','Heng','Qu','Yi','Yi','Bu','Gan','Yu','Biao','Cha','Yi','Shan','Chen','Fu','Gun','Fen','Shuai','Jie','Na','Zhong','Dan','Yi','Zhong','Zhong','Jie','Zhi','Xie','Ran','Zhi','Ren','Qin','Jin','Jun','Yuan','Mei','Chai','Ao','Niao','Hui','Ran','Jia','Tuo','Ling','Dai','Bao','Pao','Yao','Zuo','Bi','Shao','Tan','Ju','He','Xue','Xiu','Zhen','Yi','Pa','Bo','Di','Wa','Fu','Gun','Zhi','Zhi','Ran','Pan','Yi','Mao','Tuo','Na','Gou','Xuan','Zhe','Qu','Bei','Yu','Xi','Mi','Bo','Bo','Fu','Chi','Chi','Ku','Ren','Jiang','Jia','Jian','Bo','Jie','Er','Ge','Ru','Zhu','Gui','Yin','Cai','Lie','Ka','Xing','Zhuang','Dang','Xu','Kun','Ken','Niao','Shu','Jia','Kun','Cheng','Li','Juan','Shen','Pou','Ge','Yi','Yu','Zhen','Liu','Qiu','Qun','Ji','Yi','Bu','Zhuang','Shui','Sha','Qun','Li','Lian','Lian','Ku','Jian','Fou','Chan','Bi','Kun','Tao','Yuan','Ling','Chi','Chang','Chou','Duo','Biao','Liang','Shang','Pei','Pei','Fei','Yuan','Luo','Guo','Yan','Du','Ti','Zhi','Ju','Yi')


b=('Zhui','Zi','Ke','Xiang','Jian','Mian','Lan','Ti','Miao','Ji','Yun','Hui','Si','Duo','Duan','Bian','Xian','Gou','Zhui','Huan','Di','Lu','Bian','Min','Yuan','Jin','Fu','Ru','Zhen','Feng','Cui','Gao','Chan','Li','Yi','Jian','Bin','Piao','Man','Lei','Ying','Suo','Mou','Sao','Xie','Liao','Shan','Zeng','Jiang','Qian','Qiao','Huan','Jiao','Zuan','Fou','Xie','Gang','Fou','Que','Fou','Qi','Bo','Ping','Xiang','Zhao','Gang','Ying','Ying','Qing','Xia','Guan','Zun','Tan','Cheng','Qi','Weng','Ying','Lei','Tan','Lu','Guan','Wang','Wang','Gang','Wang','Han','Luo','Luo','Fu','Shen','Fa','Gu','Zhu','Ju','Mao','Gu','Min','Gang','Ba','Gua','Ti','Juan','Fu','Shen','Yan','Zhao','Zui','Gua','Zhuo','Yu','Zhi','An','Fa','Lan','Shu','Si','Pi','Ma','Liu','Ba','Fa','Li','Chao','Wei','Bi','Ji','Zeng','Chong','Liu','Ji','Juan','Mi','Zhao','Luo','Pi','Ji','Ji','Luan','Yang','Mi','Qiang','Da','Mei','Yang','You','You','Fen','Ba','Gao','Yang','Gu','Qiang','Zang','Gao','Ling','Yi','Zhu','Di','Xiu','Qiang','Yi','Xian','Rong','Qun','Qun','Qiang','Huan','Suo','Xian','Yi','Yang','Qiang','Qian','Yu','Geng','Jie','Tang','Yuan','Xi','Fan','Shan','Fen','Shan','Lian','Lei','Geng','Nou','Qiang','Chan','Yu','Gong','Yi','Chong','Weng','Fen','Hong','Chi','Chi','Cui','Fu','Xia','Ben','Yi','La','Yi','Pi','Ling','Liu','Zhi','Qu','Xi','Xie','Xiang','Xi','Xi','Ke','Qiao','Hui','Hui','Xiao','Sha','Hong','Jiang','Di','Cui','Fei','Dao','Sha','Chi','Zhu','Jian','Xuan','Chi','Pian','Zong','Wan','Hui','Hou','He','He','Han','Ao','Piao','Yi','Lian','Hou','Ao','Lin','Pen','Qiao','Ao','Fan','Yi','Hui','Xuan','Dao')


b=('You','Yang','Lu','Si','Zhi','Ying','Du','Wang','Hui','Xie','Pan','Shen','Biao','Chan','Mo','Liu','Jian','Pu','Se','Cheng','Gu','Bin','Huo','Xian','Lu','Qin','Han','Ying','Rong','Li','Jing','Xiao','Ying','Sui','Wei','Xie','Huai','Xue','Zhu','Long','Lai','Dui','Fan','Hu','Lai','Shu','Ling','Ying','Mi','Ji','Lian','Jian','Ying','Fen','Lin','Yi','Jian','Yue','Chan','Dai','Rang','Jian','Lan','Fan','Shuang','Yuan','Zhuo','Feng','She','Lei','Lan','Cong','Qu','Yong','Qian','Fa','Guan','Jue','Yan','Hao','Ying','Sa','Zan','Luan','Yan','Li','Mi','Shan','Tan','Dang','Jiao','Chan','Ying','Hao','Ba','Zhu','Lan','Lan','Nang','Wan','Luan','Xun','Xian','Yan','Gan','Yan','Yu','Huo','Biao','Mie','Guang','Deng','Hui','Xiao','Xiao','Hui','Hong','Ling','Zao','Zhuan','Jiu','Zha','Xie','Chi','Zhuo','Zai','Zai','Can','Yang','Qi','Zhong','Fen','Niu','Jiong','Wen','Pu','Yi','Lu','Chui','Pi','Kai','Pan','Yan','Kai','Pang','Mu','Chao','Liao','Gui','Kang','Dun','Guang','Xin','Zhi','Guang','Guang','Wei','Qiang','Bian','Da','Xia','Zheng','Zhu','Ke','Zhao','Fu','Ba','Xie','Xie','Ling','Zhuo','Xuan','Ju','Tan','Pao','Jiong','Pao','Tai','Tai','Bing','Yang','Tong','Shan','Zhu','Zha','Dian','Wei','Shi','Lian','Chi','Huang','Zhou','Hu','Shuo','Lan','Ting','Jiao','Xu','Heng','Quan','Lie','Huan','Yang','Xiu','Xiu','Xian','Yin','Wu','Zhou','Yao','Shi','Wei','Tong','Mie','Zai','Kai','Hong','Lao','Xia','Zhu','Xuan','Zheng','Po','Yan','Hui','Guang','Che','Hui','Kao','Ju','Fan','Shao','Ye','Hui','','Tang','Jin','Re','Lie','Xi','Fu','Jiong','Xie','Pu','Ting','Zhuo','Ting','Wan','Hai','Peng','Lang','Yan','Xu','Feng','Chi','Rong')


b=('syon','syonj','syonh','syod','syol','syolg','syolm','syolb','syols','syolt','syolp','syolh','syom','syob','syobs','syos','syoss','syong','syoj','syoch','syok','syot','syop','syoh','su','sug','sukk','sugs','sun','sunj','sunh','sud','sul','sulg','sulm','sulb','suls','sult','sulp','sulh','sum','sub','subs','sus','suss','sung','suj','such','suk','sut','sup','suh','swo','swog','swokk','swogs','swon','swonj','swonh','swod','swol','swolg','swolm','swolb','swols','swolt','swolp','swolh','swom','swob','swobs','swos','swoss','swong','swoj','swoch','swok','swot','swop','swoh','swe','sweg','swekk','swegs','swen','swenj','swenh','swed','swel','swelg','swelm','swelb','swels','swelt','swelp','swelh','swem','sweb','swebs','swes','swess','sweng','swej','swech','swek','swet','swep','sweh','swi','swig','swikk','swigs','swin','swinj','swinh','swid','swil','swilg','swilm','swilb','swils','swilt','swilp','swilh','swim','swib','swibs','swis','swiss','swing','swij','swich','swik','swit','swip','swih','syu','syug','syukk','syugs','syun','syunj','syunh','syud','syul','syulg','syulm','syulb','syuls','syult','syulp','syulh','syum','syub','syubs','syus','syuss','syung','syuj','syuch','syuk','syut','syup','syuh','seu','seug','seukk','seugs','seun','seunj','seunh','seud','seul','seulg','seulm','seulb','seuls','seult','seulp','seulh','seum','seub','seubs','seus','seuss','seung','seuj','seuch','seuk','seut','seup','seuh','sui','suig','suikk','suigs','suin','suinj','suinh','suid','suil','suilg','suilm','suilb','suils','suilt','suilp','suilh','suim','suib','suibs','suis','suiss','suing','suij','suich','suik','suit','suip','suih','si','sig','sikk','sigs','sin','sinj','sinh','sid','sil','silg','silm','silb','sils','silt','silp','silh','sim','sib','sibs','sis','siss','sing','sij','sich','sik','sit','sip','sih','ssa','ssag','ssakk','ssags','ssan','ssanj','ssanh','ssad')


b=('Zui','Can','Xu','Hui','Yin','Qie','Fen','Pi','Yue','You','Ruan','Peng','Fen','Fu','Ling','Fei','Qu','Ti','Nu','Tiao','Shuo','Zhen','Lang','Lang','Zui','Ming','Huang','Wang','Tun','Chao','Ji','Qi','Ying','Zong','Wang','Tong','Lang','Lao','Meng','Long','Mu','Deng','Wei','Mo','Ben','Zha','Shu','Shu','Mu','Zhu','Ren','Ba','Pu','Duo','Duo','Dao','Li','Gui','Ji','Jiu','Bi','Xiu','Cheng','Ci','Sha','Ru','Za','Quan','Qian','Yu','Gan','Wu','Cha','Shan','Xun','Fan','Wu','Zi','Li','Xing','Cai','Cun','Ren','Biao','Tuo','Di','Zhang','Mang','Chi','Yi','Gai','Gong','Du','Li','Qi','Shu','Gang','Tiao','Jiang','Mian','Wan','Lai','Jiu','Mang','Yang','Ma','Miao','Si','Yuan','Hang','Fei','Bei','Jie','Dong','Gao','Yao','Xian','Chu','Chun','Pa','Shu','Hua','Xin','Chou','Zhu','Chou','Song','Ban','Song','Ji','Wo','Jin','Gou','Ji','Mao','Pi','Bi','Wang','Ang','Fang','Fen','Yi','Fu','Nan','Xi','Hu','Ya','Dou','Xin','Zhen','Yao','Lin','Rui','E','Mei','Zhao','Guo','Zhi','Cong','Yun','Zui','Sheng','Shu','Zao','Di','Li','Lu','Jian','Cheng','Song','Qiang','Feng','Zhan','Xiao','Xian','Ku','Ping','Tai','Xi','Zhi','Guai','Xiao','Jia','Jia','Gou','Bao','Mo','Yi','Ye','Ye','Shi','Nie','Bi','Duo','Yi','Ling','Bing','Ni','La','He','Ban','Fan','Zhong','Dai','Ci','Yang','Fu','Bai','Mou','Gan','Qi','Ran','Rou','Mao','Shao','Song','Zhe','Xia','You','Shen','Gui','Tuo','Zha','Nan','Ning','Yong','Di','Zhi','Zha','Cha','Dan','Gu','Bu','Jiu','Ao','Fu','Jian','Ba','Duo','Ke','Nai','Zhu','Bi','Liu','Chai','Shan','Si','Chu','Pei','Shi','Guai','Zha','Yao','Cheng','Jiu','Shi')


b=('duil','duilg','duilm','duilb','duils','duilt','duilp','duilh','duim','duib','duibs','duis','duiss','duing','duij','duich','duik','duit','duip','duih','di','dig','dikk','digs','din','dinj','dinh','did','dil','dilg','dilm','dilb','dils','dilt','dilp','dilh','dim','dib','dibs','dis','diss','ding','dij','dich','dik','dit','dip','dih','tta','ttag','ttakk','ttags','ttan','ttanj','ttanh','ttad','ttal','ttalg','ttalm','ttalb','ttals','ttalt','ttalp','ttalh','ttam','ttab','ttabs','ttas','ttass','ttang','ttaj','ttach','ttak','ttat','ttap','ttah','ttae','ttaeg','ttaekk','ttaegs','ttaen','ttaenj','ttaenh','ttaed','ttael','ttaelg','ttaelm','ttaelb','ttaels','ttaelt','ttaelp','ttaelh','ttaem','ttaeb','ttaebs','ttaes','ttaess','ttaeng','ttaej','ttaech','ttaek','ttaet','ttaep','ttaeh','ttya','ttyag','ttyakk','ttyags','ttyan','ttyanj','ttyanh','ttyad','ttyal','ttyalg','ttyalm','ttyalb','ttyals','ttyalt','ttyalp','ttyalh','ttyam','ttyab','ttyabs','ttyas','ttyass','ttyang','ttyaj','ttyach','ttyak','ttyat','ttyap','ttyah','ttyae','ttyaeg','ttyaekk','ttyaegs','ttyaen','ttyaenj','ttyaenh','ttyaed','ttyael','ttyaelg','ttyaelm','ttyaelb','ttyaels','ttyaelt','ttyaelp','ttyaelh','ttyaem','ttyaeb','ttyaebs','ttyaes','ttyaess','ttyaeng','ttyaej','ttyaech','ttyaek','ttyaet','ttyaep','ttyaeh','tteo','tteog','tteokk','tteogs','tteon','tteonj','tteonh','tteod','tteol','tteolg','tteolm','tteolb','tteols','tteolt','tteolp','tteolh','tteom','tteob','tteobs','tteos','tteoss','tteong','tteoj','tteoch','tteok','tteot','tteop','tteoh','tte','tteg','ttekk','ttegs','tten','ttenj','ttenh','tted','ttel','ttelg','ttelm','ttelb','ttels','ttelt','ttelp','ttelh','ttem','tteb','ttebs','ttes','ttess','tteng','ttej','ttech','ttek','ttet','ttep','tteh','ttyeo','ttyeog','ttyeokk','ttyeogs','ttyeon','ttyeonj','ttyeonh','ttyeod','ttyeol','ttyeolg','ttyeolm','ttyeolb','ttyeols','ttyeolt','ttyeolp','ttyeolh','ttyeom','ttyeob','ttyeobs','ttyeos','ttyeoss','ttyeong','ttyeoj','ttyeoch','ttyeok','ttyeot','ttyeop','ttyeoh','ttye','ttyeg','ttyekk','ttyegs','ttyen','ttyenj','ttyenh','ttyed','ttyel','ttyelg','ttyelm','ttyelb')


b=('Ti','Li','Bin','Zong','Di','Peng','Song','Zheng','Quan','Zong','Shun','Jian','Tuo','Hu','La','Jiu','Qi','Lian','Zhen','Bin','Peng','Ma','San','Man','Man','Seng','Xu','Lie','Qian','Qian','Nang','Huan','Kuo','Ning','Bin','Lie','Rang','Dou','Dou','Nao','Hong','Xi','Dou','Han','Dou','Dou','Jiu','Chang','Yu','Yu','Ge','Yan','Fu','Qin','Gui','Zong','Liu','Gui','Shang','Yu','Gui','Mei','Ji','Qi','Ga','Kui','Hun','Ba','Po','Mei','Xu','Yan','Xiao','Liang','Yu','Tui','Qi','Wang','Liang','Wei','Gan','Chi','Piao','Bi','Mo','Ji','Xu','Chou','Yan','Zhan','Yu','Dao','Ren','Jie','Ba','Hong','Tuo','Diao','Ji','Xu','E','E','Sha','Hang','Tun','Mo','Jie','Shen','Ban','Yuan','Pi','Lu','Wen','Hu','Lu','Za','Fang','Fen','Na','You','Pian','Mo','He','Xia','Qu','Han','Pi','Ling','Tuo','Bo','Qiu','Ping','Fu','Bi','Ci','Wei','Ju','Diao','Ba','You','Gun','Pi','Nian','Xing','Tai','Bao','Fu','Zha','Ju','Gu','Shi','Dong','Dai','Ta','Jie','Shu','Hou','Xiang','Er','An','Wei','Zhao','Zhu','Yin','Lie','Luo','Tong','Ti','Yi','Bing','Wei','Jiao','Ku','Gui','Xian','Ge','Hui','Lao','Fu','Kao','Xiu','Duo','Jun','Ti','Mian','Shao','Zha','Suo','Qin','Yu','Nei','Zhe','Gun','Geng','Su','Wu','Qiu','Shan','Pu','Huan','Tiao','Li','Sha','Sha','Kao','Meng','Cheng','Li','Zou','Xi','Yong','Shen','Zi','Qi','Zheng','Xiang','Nei','Chun','Ji','Diao','Qie','Gu','Zhou','Dong','Lai','Fei','Ni','Yi','Kun','Lu','Jiu','Chang','Jing','Lun','Ling','Zou','Li','Meng','Zong','Zhi','Nian','Hu','Yu','Di','Shi','Shen','Huan','Ti','Hou','Xing','Zhu','La','Zong','Zei','Bian','Bian')


b=('Yu','Cui','Ya','Zhu','Cu','Dan','Shen','Zhong','Chi','Yu','Hou','Feng','La','Yang','Chen','Tu','Yu','Guo','Wen','Huan','Ku','Jia','Yin','Yi','Lou','Sao','Jue','Chi','Xi','Guan','Yi','Wen','Ji','Chuang','Ban','Hui','Liu','Chai','Shou','Nue','Dian','Da','Bie','Tan','Zhang','Biao','Shen','Cu','Luo','Yi','Zong','Chou','Zhang','Zhai','Sou','Se','Que','Diao','Lou','Lou','Mo','Qin','Yin','Ying','Huang','Fu','Liao','Long','Qiao','Liu','Lao','Xian','Fei','Dan','Yin','He','Ai','Ban','Xian','Guan','Gui','Nong','Yu','Wei','Yi','Yong','Pi','Lei','Li','Shu','Dan','Lin','Dian','Lin','Lai','Bie','Ji','Chi','Yang','Xuan','Jie','Zheng','Me','Li','Huo','Lai','Ji','Dian','Xuan','Ying','Yin','Qu','Yong','Tan','Dian','Luo','Luan','Luan','Bo','Bo','Gui','Ba','Fa','Deng','Fa','Bai','Bai','Qie','Ji','Zao','Zao','Mao','De','Pa','Jie','Huang','Gui','Ci','Ling','Gao','Mo','Ji','Jiao','Peng','Gao','Ai','E','Hao','Han','Bi','Wan','Chou','Qian','Xi','Ai','Xiao','Hao','Huang','Hao','Ze','Cui','Hao','Xiao','Ye','Po','Hao','Jiao','Ai','Xing','Huang','Li','Piao','He','Jiao','Pi','Gan','Pao','Zhou','Jun','Qiu','Cun','Que','Zha','Gu','Jun','Jun','Zhou','Zha','Gu','Zhao','Du','Min','Qi','Ying','Yu','Bei','Zhao','Zhong','Pen','He','Ying','He','Yi','Bo','Wan','He','Ang','Zhan','Yan','Jian','He','Yu','Kui','Fan','Gai','Dao','Pan','Fu','Qiu','Sheng','Dao','Lu','Zhan','Meng','Li','Jin','Xu','Jian','Pan','Guan','An','Lu','Xu','Zhou','Dang','An','Gu','Li','Mu','Ding','Gan','Xu','Mang','Wang','Zhi','Qi','Yuan','Tian','Xiang','Dun','Xin','Xi','Pan','Feng','Dun','Min')


b=('E','Cheng','Xing','Ai','Lu','Zhui','Zhou','She','Pian','Kun','Tao','Lai','Zong','Ke','Qi','Qi','Yan','Fei','Sao','Yan','Ge','Yao','Wu','Pian','Cong','Pian','Qian','Fei','Huang','Qian','Huo','Yu','Ti','Quan','Xia','Zong','Kui','Rou','Si','Gua','Tuo','Gui','Sou','Qian','Cheng','Zhi','Liu','Peng','Teng','Xi','Cao','Du','Yan','Yuan','Zou','Sao','Shan','Qi','Zhi','Shuang','Lu','Xi','Luo','Zhang','Mo','Ao','Can','Biao','Cong','Qu','Bi','Zhi','Yu','Xu','Hua','Bo','Su','Xiao','Lin','Zhan','Dun','Liu','Tuo','Ceng','Dian','Jiao','Tie','Yan','Luo','Zhan','Jing','Yi','Ye','Tuo','Pin','Zhou','Yan','Long','Lu','Teng','Xiang','Ji','Shuang','Ju','Xi','Huan','Li','Biao','Ma','Yu','Tuo','Xun','Chi','Qu','Ri','Bo','Lu','Zang','Shi','Si','Fu','Ju','Zou','Zhu','Tuo','Nu','Jia','Yi','Dai','Xiao','Ma','Yin','Jiao','Hua','Luo','Hai','Pian','Biao','Li','Cheng','Yan','Xing','Qin','Jun','Qi','Qi','Ke','Zhui','Zong','Su','Can','Pian','Zhi','Kui','Sao','Wu','Ao','Liu','Qian','Shan','Biao','Luo','Cong','Chan','Zhou','Ji','Shuang','Xiang','Gu','Wei','Wei','Wei','Yu','Gan','Yi','Ang','Tou','Jie','Bao','Bei','Ci','Ti','Di','Ku','Hai','Qiao','Hou','Kua','Ge','Tui','Geng','Pian','Bi','Ke','Qia','Yu','Sui','Lou','Bo','Xiao','Bang','Bo','Ci','Kuan','Bin','Mo','Liao','Lou','Xiao','Du','Zang','Sui','Ti','Bin','Kuan','Lu','Gao','Gao','Qiao','Kao','Qiao','Lao','Sao','Biao','Kun','Kun','Di','Fang','Xiu','Ran','Mao','Dan','Kun','Bin','Fa','Tiao','Pi','Zi','Fa','Ran','Ti','Bao','Bi','Mao','Fu','Er','Rong','Qu','Gong','Xiu','Kuo','Ji','Peng','Zhua','Shao','Suo')


b=('Song','Wei','Hong','Wa','Lou','Ya','Rao','Jiao','Luan','Ping','Xian','Shao','Li','Cheng','Xie','Mang','Fu','Suo','Mei','Wei','Ke','Chuo','Chuo','Ting','Niang','Xing','Nan','Yu','Na','Pou','Nei','Juan','Shen','Zhi','Han','Di','Zhuang','E','Pin','Tui','Xian','Mian','Wu','Yan','Wu','Ai','Yan','Yu','Si','Yu','Wa','Li','Xian','Ju','Qu','Zhui','Qi','Xian','Zhuo','Dong','Chang','Lu','Ai','E','E','Lou','Mian','Cong','Pou','Ju','Po','Cai','Ling','Wan','Biao','Xiao','Shu','Qi','Hui','Fan','Wo','Rui','Tan','Fei','Fei','Jie','Tian','Ni','Quan','Jing','Hun','Jing','Qian','Dian','Xing','Hu','Wan','Lai','Bi','Yin','Chou','Nao','Fu','Jing','Lun','An','Lan','Kun','Yin','Ya','Ju','Li','Dian','Xian','Hua','Hua','Ying','Chan','Shen','Ting','Dang','Yao','Wu','Nan','Chuo','Jia','Tou','Xu','Yu','Wei','Di','Rou','Mei','Dan','Ruan','Qin','Hui','Wo','Qian','Chun','Miao','Fu','Jie','Duan','Yi','Zhong','Mei','Huang','Mian','An','Ying','Xuan','Jie','Wei','Mei','Yuan','Zheng','Qiu','Shi','Xie','Tuo','Lian','Mao','Ran','Si','Pian','Wei','Wa','Cu','Hu','Ao','Jie','Bao','Xu','Tou','Gui','Chu','Yao','Pi','Xi','Yuan','Ying','Rong','Ru','Chi','Liu','Mei','Pan','Ao','Ma','Gou','Kui','Qin','Jia','Sao','Zhen','Yuan','Jie','Rong','Ming','Ying','Ji','Su','Niao','Xian','Tao','Pang','Lang','Nao','Bao','Ai','Pi','Pin','Yi','Piao','Yu','Lei','Xuan','Man','Yi','Zhang','Kang','Yong','Ni','Li','Di','Gui','Yan','Jin','Zhuan','Chang','Ze','Han','Nen','Lao','Mo','Zhe','Hu','Hu','Ao','Nen','Qiang','Ma','Pie','Gu','Wu','Qiao','Tuo','Zhan','Miao','Xian','Xian','Mo','Liao','Lian','Hua')


b=('jeo','jeog','jeokk','jeogs','jeon','jeonj','jeonh','jeod','jeol','jeolg','jeolm','jeolb','jeols','jeolt','jeolp','jeolh','jeom','jeob','jeobs','jeos','jeoss','jeong','jeoj','jeoch','jeok','jeot','jeop','jeoh','je','jeg','jekk','jegs','jen','jenj','jenh','jed','jel','jelg','jelm','jelb','jels','jelt','jelp','jelh','jem','jeb','jebs','jes','jess','jeng','jej','jech','jek','jet','jep','jeh','jyeo','jyeog','jyeokk','jyeogs','jyeon','jyeonj','jyeonh','jyeod','jyeol','jyeolg','jyeolm','jyeolb','jyeols','jyeolt','jyeolp','jyeolh','jyeom','jyeob','jyeobs','jyeos','jyeoss','jyeong','jyeoj','jyeoch','jyeok','jyeot','jyeop','jyeoh','jye','jyeg','jyekk','jyegs','jyen','jyenj','jyenh','jyed','jyel','jyelg','jyelm','jyelb','jyels','jyelt','jyelp','jyelh','jyem','jyeb','jyebs','jyes','jyess','jyeng','jyej','jyech','jyek','jyet','jyep','jyeh','jo','jog','jokk','jogs','jon','jonj','jonh','jod','jol','jolg','jolm','jolb','jols','jolt','jolp','jolh','jom','job','jobs','jos','joss','jong','joj','joch','jok','jot','jop','joh','jwa','jwag','jwakk','jwags','jwan','jwanj','jwanh','jwad','jwal','jwalg','jwalm','jwalb','jwals','jwalt','jwalp','jwalh','jwam','jwab','jwabs','jwas','jwass','jwang','jwaj','jwach','jwak','jwat','jwap','jwah','jwae','jwaeg','jwaekk','jwaegs','jwaen','jwaenj','jwaenh','jwaed','jwael','jwaelg','jwaelm','jwaelb','jwaels','jwaelt','jwaelp','jwaelh','jwaem','jwaeb','jwaebs','jwaes','jwaess','jwaeng','jwaej','jwaech','jwaek','jwaet','jwaep','jwaeh','joe','joeg','joekk','joegs','joen','joenj','joenh','joed','joel','joelg','joelm','joelb','joels','joelt','joelp','joelh','joem','joeb','joebs','joes','joess','joeng','joej','joech','joek','joet','joep','joeh','jyo','jyog','jyokk','jyogs','jyon','jyonj','jyonh','jyod','jyol','jyolg','jyolm','jyolb','jyols','jyolt','jyolp','jyolh','jyom','jyob','jyobs','jyos','jyoss','jyong','jyoj','jyoch','jyok','jyot','jyop','jyoh','ju','jug','jukk','jugs')


b=('Zhi','Liu','Mei','Li','Rong','Zha','Zao','Biao','Zhan','Zhi','Long','Dong','Lu','Sheng','Li','Lan','Yong','Shu','Xun','Shuan','Qi','Zhen','Qi','Li','Yi','Xiang','Zhen','Li','Se','Gua','Kan','Ben','Ren','Xiao','Bai','Ren','Bing','Zi','Chou','Yi','Ci','Xu','Zhu','Jian','Zui','Er','Er','You','Fa','Gong','Kao','Lao','Zhan','Lie','Yin','Yang','He','Gen','Yi','Shi','Ge','Zai','Luan','Fu','Jie','Heng','Gui','Tao','Guang','Wei','Kuang','Ru','An','An','Juan','Yi','Zhuo','Ku','Zhi','Qiong','Tong','Sang','Sang','Huan','Ju','Jiu','Xue','Duo','Zhui','Yu','Zan','Kasei','Ying','Jie','Liu','Zhan','Ya','Rao','Zhen','Dang','Qi','Qiao','Hua','Gui','Jiang','Zhuang','Xun','Suo','Sha','Zhen','Bei','Ting','Kuo','Jing','Po','Ben','Fu','Rui','Tong','Jue','Xi','Lang','Liu','Feng','Qi','Wen','Jun','Gan','Su','Liang','Qiu','Ting','You','Mei','Bang','Long','Peng','Zhuang','Di','Xuan','Tu','Zao','Ao','Gu','Bi','Di','Han','Zi','Zhi','Ren','Bei','Geng','Jian','Huan','Wan','Nuo','Jia','Tiao','Ji','Xiao','Lu','Hun','Shao','Cen','Fen','Song','Meng','Wu','Li','Li','Dou','Qin','Ying','Suo','Ju','Ti','Xie','Kun','Zhuo','Shu','Chan','Fan','Wei','Jing','Li','Bin','Xia','Fo','Tao','Zhi','Lai','Lian','Jian','Zhuo','Ling','Li','Qi','Bing','Lun','Cong','Qian','Mian','Qi','Qi','Cai','Gun','Chan','De','Fei','Pai','Bang','Bang','Hun','Zong','Cheng','Zao','Ji','Li','Peng','Yu','Yu','Gu','Jun','Dong','Tang','Gang','Wang','Di','Cuo','Fan','Cheng','Zhan','Qi','Yuan','Yan','Yu','Quan','Yi','Sen','Ren','Chui','Leng','Qi','Zhuo','Fu','Ke','Lai','Zou','Zou','Zhao','Guan','Fen','Fen','Shen','Qing','Ni')


b=('jjuim','jjuib','jjuibs','jjuis','jjuiss','jjuing','jjuij','jjuich','jjuik','jjuit','jjuip','jjuih','jji','jjig','jjikk','jjigs','jjin','jjinj','jjinh','jjid','jjil','jjilg','jjilm','jjilb','jjils','jjilt','jjilp','jjilh','jjim','jjib','jjibs','jjis','jjiss','jjing','jjij','jjich','jjik','jjit','jjip','jjih','cha','chag','chakk','chags','chan','chanj','chanh','chad','chal','chalg','chalm','chalb','chals','chalt','chalp','chalh','cham','chab','chabs','chas','chass','chang','chaj','chach','chak','chat','chap','chah','chae','chaeg','chaekk','chaegs','chaen','chaenj','chaenh','chaed','chael','chaelg','chaelm','chaelb','chaels','chaelt','chaelp','chaelh','chaem','chaeb','chaebs','chaes','chaess','chaeng','chaej','chaech','chaek','chaet','chaep','chaeh','chya','chyag','chyakk','chyags','chyan','chyanj','chyanh','chyad','chyal','chyalg','chyalm','chyalb','chyals','chyalt','chyalp','chyalh','chyam','chyab','chyabs','chyas','chyass','chyang','chyaj','chyach','chyak','chyat','chyap','chyah','chyae','chyaeg','chyaekk','chyaegs','chyaen','chyaenj','chyaenh','chyaed','chyael','chyaelg','chyaelm','chyaelb','chyaels','chyaelt','chyaelp','chyaelh','chyaem','chyaeb','chyaebs','chyaes','chyaess','chyaeng','chyaej','chyaech','chyaek','chyaet','chyaep','chyaeh','cheo','cheog','cheokk','cheogs','cheon','cheonj','cheonh','cheod','cheol','cheolg','cheolm','cheolb','cheols','cheolt','cheolp','cheolh','cheom','cheob','cheobs','cheos','cheoss','cheong','cheoj','cheoch','cheok','cheot','cheop','cheoh','che','cheg','chekk','chegs','chen','chenj','chenh','ched','chel','chelg','chelm','chelb','chels','chelt','chelp','chelh','chem','cheb','chebs','ches','chess','cheng','chej','chech','chek','chet','chep','cheh','chyeo','chyeog','chyeokk','chyeogs','chyeon','chyeonj','chyeonh','chyeod','chyeol','chyeolg','chyeolm','chyeolb','chyeols','chyeolt','chyeolp','chyeolh','chyeom','chyeob','chyeobs','chyeos','chyeoss','chyeong','chyeoj','chyeoch','chyeok','chyeot','chyeop','chyeoh','chye','chyeg','chyekk','chyegs','chyen','chyenj','chyenh','chyed','chyel','chyelg','chyelm','chyelb','chyels','chyelt','chyelp','chyelh','chyem','chyeb','chyebs','chyes')


b=('Shou','Yi','Zhi','Gu','Chu','Jiang','Feng','Bei','Zhai','Bian','Sui','Qun','Ling','Fu','Cuo','Xia','Xiong','Xie','Nao','Xia','Kui','Xi','Wai','Yuan','Mao','Su','Duo','Duo','Ye','Qing','Wai','Gou','Gou','Qi','Meng','Meng','Yin','Huo','Chen','Da','Ze','Tian','Tai','Fu','Guai','Yao','Yang','Hang','Gao','Shi','Tao','Tai','Tou','Yan','Bi','Yi','Kua','Jia','Duo','Hua','Kuang','Yun','Jia','Ba','En','Lian','Huan','Di','Yan','Pao','Juan','Qi','Nai','Feng','Xie','Fen','Dian','Quan','Kui','Zou','Huan','Qi','Kai','Zha','Ben','Yi','Jiang','Tao','Zang','Ben','Xi','Huang','Fei','Diao','Xun','Beng','Dian','Ao','She','Weng','Ha','Ao','Wu','Ao','Jiang','Lian','Duo','Yun','Jiang','Shi','Fen','Huo','Bi','Luan','Duo','Nu','Nu','Ding','Nai','Qian','Jian','Ta','Jiu','Nuan','Cha','Hao','Xian','Fan','Ji','Shuo','Ru','Fei','Wang','Hong','Zhuang','Fu','Ma','Dan','Ren','Fu','Jing','Yan','Hai','Wen','Zhong','Pa','Du','Ji','Keng','Zhong','Yao','Jin','Yun','Miao','Fou','Chi','Yue','Zhuang','Niu','Yan','Na','Xin','Fen','Bi','Yu','Tuo','Feng','Wan','Fang','Wu','Yu','Gui','Du','Ba','Ni','Zhou','Zhuo','Zhao','Da','Nai','Yuan','Tou','Xian','Zhi','E','Mei','Mo','Qi','Bi','Shen','Qie','E','He','Xu','Fa','Zheng','Min','Ban','Mu','Fu','Ling','Zi','Zi','Shi','Ran','Shan','Yang','Man','Jie','Gu','Si','Xing','Wei','Zi','Ju','Shan','Pin','Ren','Yao','Dong','Jiang','Shu','Ji','Gai','Xiang','Hua','Juan','Jiao','Gou','Lao','Jian','Jian','Yi','Nian','Zhi','Ji','Ji','Xian','Heng','Guang','Jun','Kua','Yan','Ming','Lie','Pei','E','You','Yan','Cha','Shen','Yin','Shi','Gui','Quan','Zi')


b=('Zhui','Ping','Bian','Zhou','Zhen','Lei','Ci','Ying','Qi','Xian','Lou','Di','Ou','Meng','Zhuan','Beng','Lin','Zeng','Wu','Pi','Dan','Weng','Ying','Yan','Gan','Dai','Shen','Tian','Tian','Han','Chang','Sheng','Qing','Shen','Chan','Chan','Rui','Sheng','Su','Shen','Yong','Shuai','Lu','Fu','Yong','Beng','Feng','Ning','Tian','You','Jia','Shen','Zha','Dian','Fu','Nan','Dian','Ping','Ting','Hua','Ting','Zhen','Zai','Meng','Bi','Bi','Liu','Xun','Liu','Chang','Mu','Yun','Fan','Fu','Geng','Tian','Jie','Jie','Quan','Wei','Fu','Tian','Mu','Duo','Pan','Jiang','Wa','Da','Nan','Liu','Ben','Zhen','Chu','Mu','Mu','Ce','Tian','Gai','Bi','Da','Zhi','Lue','Qi','Lue','Pan','Yi','Fan','Hua','She','Yu','Mu','Jun','Yi','Liu','She','Die','Chou','Hua','Dang','Zhui','Ji','Wan','Jiang','Cheng','Chang','Tun','Lei','Ji','Cha','Liu','Die','Tuan','Lin','Jiang','Jiang','Chou','Pi','Die','Die','Pi','Jie','Dan','Shu','Shu','Zhi','Yi','Ne','Nai','Ding','Bi','Jie','Liao','Gang','Ge','Jiu','Zhou','Xia','Shan','Xu','Nue','Li','Yang','Chen','You','Ba','Jie','Jue','Qi','Xia','Cui','Bi','Yi','Li','Zong','Chuang','Feng','Zhu','Pao','Pi','Gan','Ke','Ci','Xue','Zhi','Dan','Zhen','Fa','Zhi','Teng','Ju','Ji','Fei','Ju','Shan','Jia','Xuan','Zha','Bing','Nie','Zheng','Yong','Jing','Quan','Teng','Tong','Yi','Jie','Wei','Hui','Tan','Yang','Chi','Zhi','Hen','Ya','Mei','Dou','Jing','Xiao','Tong','Tu','Mang','Pi','Xiao','Suan','Fu','Li','Zhi','Cuo','Duo','Wu','Sha','Lao','Shou','Huan','Xian','Yi','Beng','Zhang','Guan','Tan','Fei','Ma','Lin','Chi','Ji','Tian','An','Chi','Bi','Bi','Min','Gu','Dui','E','Wei')


b=('leoss','leong','leoj','leoch','leok','leot','leop','leoh','le','leg','lekk','legs','len','lenj','lenh','led','lel','lelg','lelm','lelb','lels','lelt','lelp','lelh','lem','leb','lebs','les','less','leng','lej','lech','lek','let','lep','leh','lyeo','lyeog','lyeokk','lyeogs','lyeon','lyeonj','lyeonh','lyeod','lyeol','lyeolg','lyeolm','lyeolb','lyeols','lyeolt','lyeolp','lyeolh','lyeom','lyeob','lyeobs','lyeos','lyeoss','lyeong','lyeoj','lyeoch','lyeok','lyeot','lyeop','lyeoh','lye','lyeg','lyekk','lyegs','lyen','lyenj','lyenh','lyed','lyel','lyelg','lyelm','lyelb','lyels','lyelt','lyelp','lyelh','lyem','lyeb','lyebs','lyes','lyess','lyeng','lyej','lyech','lyek','lyet','lyep','lyeh','lo','log','lokk','logs','lon','lonj','lonh','lod','lol','lolg','lolm','lolb','lols','lolt','lolp','lolh','lom','lob','lobs','los','loss','long','loj','loch','lok','lot','lop','loh','lwa','lwag','lwakk','lwags','lwan','lwanj','lwanh','lwad','lwal','lwalg','lwalm','lwalb','lwals','lwalt','lwalp','lwalh','lwam','lwab','lwabs','lwas','lwass','lwang','lwaj','lwach','lwak','lwat','lwap','lwah','lwae','lwaeg','lwaekk','lwaegs','lwaen','lwaenj','lwaenh','lwaed','lwael','lwaelg','lwaelm','lwaelb','lwaels','lwaelt','lwaelp','lwaelh','lwaem','lwaeb','lwaebs','lwaes','lwaess','lwaeng','lwaej','lwaech','lwaek','lwaet','lwaep','lwaeh','loe','loeg','loekk','loegs','loen','loenj','loenh','loed','loel','loelg','loelm','loelb','loels','loelt','loelp','loelh','loem','loeb','loebs','loes','loess','loeng','loej','loech','loek','loet','loep','loeh','lyo','lyog','lyokk','lyogs','lyon','lyonj','lyonh','lyod','lyol','lyolg','lyolm','lyolb','lyols','lyolt','lyolp','lyolh','lyom','lyob','lyobs','lyos','lyoss','lyong','lyoj','lyoch','lyok','lyot','lyop','lyoh','lu','lug','lukk','lugs','lun','lunj','lunh','lud','lul','lulg','lulm','lulb','luls','lult','lulp','lulh','lum','lub','lubs','lus','luss','lung','luj','luch')


b=('moen','moenj','moenh','moed','moel','moelg','moelm','moelb','moels','moelt','moelp','moelh','moem','moeb','moebs','moes','moess','moeng','moej','moech','moek','moet','moep','moeh','myo','myog','myokk','myogs','myon','myonj','myonh','myod','myol','myolg','myolm','myolb','myols','myolt','myolp','myolh','myom','myob','myobs','myos','myoss','myong','myoj','myoch','myok','myot','myop','myoh','mu','mug','mukk','mugs','mun','munj','munh','mud','mul','mulg','mulm','mulb','muls','mult','mulp','mulh','mum','mub','mubs','mus','muss','mung','muj','much','muk','mut','mup','muh','mwo','mwog','mwokk','mwogs','mwon','mwonj','mwonh','mwod','mwol','mwolg','mwolm','mwolb','mwols','mwolt','mwolp','mwolh','mwom','mwob','mwobs','mwos','mwoss','mwong','mwoj','mwoch','mwok','mwot','mwop','mwoh','mwe','mweg','mwekk','mwegs','mwen','mwenj','mwenh','mwed','mwel','mwelg','mwelm','mwelb','mwels','mwelt','mwelp','mwelh','mwem','mweb','mwebs','mwes','mwess','mweng','mwej','mwech','mwek','mwet','mwep','mweh','mwi','mwig','mwikk','mwigs','mwin','mwinj','mwinh','mwid','mwil','mwilg','mwilm','mwilb','mwils','mwilt','mwilp','mwilh','mwim','mwib','mwibs','mwis','mwiss','mwing','mwij','mwich','mwik','mwit','mwip','mwih','myu','myug','myukk','myugs','myun','myunj','myunh','myud','myul','myulg','myulm','myulb','myuls','myult','myulp','myulh','myum','myub','myubs','myus','myuss','myung','myuj','myuch','myuk','myut','myup','myuh','meu','meug','meukk','meugs','meun','meunj','meunh','meud','meul','meulg','meulm','meulb','meuls','meult','meulp','meulh','meum','meub','meubs','meus','meuss','meung','meuj','meuch','meuk','meut','meup','meuh','mui','muig','muikk','muigs','muin','muinj','muinh','muid','muil','muilg','muilm','muilb','muils','muilt','muilp','muilh','muim','muib','muibs','muis','muiss','muing','muij','muich','muik','muit','muip','muih','mi','mig','mikk','migs','min','minj','minh','mid')


b=('ppess','ppeng','ppej','ppech','ppek','ppet','ppep','ppeh','ppyeo','ppyeog','ppyeokk','ppyeogs','ppyeon','ppyeonj','ppyeonh','ppyeod','ppyeol','ppyeolg','ppyeolm','ppyeolb','ppyeols','ppyeolt','ppyeolp','ppyeolh','ppyeom','ppyeob','ppyeobs','ppyeos','ppyeoss','ppyeong','ppyeoj','ppyeoch','ppyeok','ppyeot','ppyeop','ppyeoh','ppye','ppyeg','ppyekk','ppyegs','ppyen','ppyenj','ppyenh','ppyed','ppyel','ppyelg','ppyelm','ppyelb','ppyels','ppyelt','ppyelp','ppyelh','ppyem','ppyeb','ppyebs','ppyes','ppyess','ppyeng','ppyej','ppyech','ppyek','ppyet','ppyep','ppyeh','ppo','ppog','ppokk','ppogs','ppon','pponj','pponh','ppod','ppol','ppolg','ppolm','ppolb','ppols','ppolt','ppolp','ppolh','ppom','ppob','ppobs','ppos','pposs','ppong','ppoj','ppoch','ppok','ppot','ppop','ppoh','ppwa','ppwag','ppwakk','ppwags','ppwan','ppwanj','ppwanh','ppwad','ppwal','ppwalg','ppwalm','ppwalb','ppwals','ppwalt','ppwalp','ppwalh','ppwam','ppwab','ppwabs','ppwas','ppwass','ppwang','ppwaj','ppwach','ppwak','ppwat','ppwap','ppwah','ppwae','ppwaeg','ppwaekk','ppwaegs','ppwaen','ppwaenj','ppwaenh','ppwaed','ppwael','ppwaelg','ppwaelm','ppwaelb','ppwaels','ppwaelt','ppwaelp','ppwaelh','ppwaem','ppwaeb','ppwaebs','ppwaes','ppwaess','ppwaeng','ppwaej','ppwaech','ppwaek','ppwaet','ppwaep','ppwaeh','ppoe','ppoeg','ppoekk','ppoegs','ppoen','ppoenj','ppoenh','ppoed','ppoel','ppoelg','ppoelm','ppoelb','ppoels','ppoelt','ppoelp','ppoelh','ppoem','ppoeb','ppoebs','ppoes','ppoess','ppoeng','ppoej','ppoech','ppoek','ppoet','ppoep','ppoeh','ppyo','ppyog','ppyokk','ppyogs','ppyon','ppyonj','ppyonh','ppyod','ppyol','ppyolg','ppyolm','ppyolb','ppyols','ppyolt','ppyolp','ppyolh','ppyom','ppyob','ppyobs','ppyos','ppyoss','ppyong','ppyoj','ppyoch','ppyok','ppyot','ppyop','ppyoh','ppu','ppug','ppukk','ppugs','ppun','ppunj','ppunh','ppud','ppul','ppulg','ppulm','ppulb','ppuls','ppult','ppulp','ppulh','ppum','ppub','ppubs','ppus','ppuss','ppung','ppuj','ppuch','ppuk','pput','ppup','ppuh','ppwo','ppwog','ppwokk','ppwogs','ppwon','ppwonj','ppwonh','ppwod','ppwol','ppwolg','ppwolm','ppwolb','ppwols','ppwolt','ppwolp','ppwolh','ppwom','ppwob','ppwobs','ppwos','ppwoss','ppwong','ppwoj','ppwoch')


b=('kwon','kwonj','kwonh','kwod','kwol','kwolg','kwolm','kwolb','kwols','kwolt','kwolp','kwolh','kwom','kwob','kwobs','kwos','kwoss','kwong','kwoj','kwoch','kwok','kwot','kwop','kwoh','kwe','kweg','kwekk','kwegs','kwen','kwenj','kwenh','kwed','kwel','kwelg','kwelm','kwelb','kwels','kwelt','kwelp','kwelh','kwem','kweb','kwebs','kwes','kwess','kweng','kwej','kwech','kwek','kwet','kwep','kweh','kwi','kwig','kwikk','kwigs','kwin','kwinj','kwinh','kwid','kwil','kwilg','kwilm','kwilb','kwils','kwilt','kwilp','kwilh','kwim','kwib','kwibs','kwis','kwiss','kwing','kwij','kwich','kwik','kwit','kwip','kwih','kyu','kyug','kyukk','kyugs','kyun','kyunj','kyunh','kyud','kyul','kyulg','kyulm','kyulb','kyuls','kyult','kyulp','kyulh','kyum','kyub','kyubs','kyus','kyuss','kyung','kyuj','kyuch','kyuk','kyut','kyup','kyuh','keu','keug','keukk','keugs','keun','keunj','keunh','keud','keul','keulg','keulm','keulb','keuls','keult','keulp','keulh','keum','keub','keubs','keus','keuss','keung','keuj','keuch','keuk','keut','keup','keuh','kui','kuig','kuikk','kuigs','kuin','kuinj','kuinh','kuid','kuil','kuilg','kuilm','kuilb','kuils','kuilt','kuilp','kuilh','kuim','kuib','kuibs','kuis','kuiss','kuing','kuij','kuich','kuik','kuit','kuip','kuih','ki','kig','kikk','kigs','kin','kinj','kinh','kid','kil','kilg','kilm','kilb','kils','kilt','kilp','kilh','kim','kib','kibs','kis','kiss','king','kij','kich','kik','kit','kip','kih','ta','tag','takk','tags','tan','tanj','tanh','tad','tal','talg','talm','talb','tals','talt','talp','talh','tam','tab','tabs','tas','tass','tang','taj','tach','tak','tat','tap','tah','tae','taeg','taekk','taegs','taen','taenj','taenh','taed','tael','taelg','taelm','taelb','taels','taelt','taelp','taelh','taem','taeb','taebs','taes','taess','taeng','taej','taech','taek','taet','taep','taeh','tya','tyag','tyakk','tyags','tyan','tyanj','tyanh','tyad')


b=('Yun','Bei','Ang','Ze','Ban','Jie','Kun','Sheng','Hu','Fang','Hao','Gui','Chang','Xuan','Ming','Hun','Fen','Qin','Hu','Yi','Xi','Xin','Yan','Ze','Fang','Tan','Shen','Ju','Yang','Zan','Bing','Xing','Ying','Xuan','Po','Zhen','Ling','Chun','Hao','Mei','Zuo','Mo','Bian','Xu','Hun','Zhao','Zong','Shi','Shi','Yu','Fei','Die','Mao','Ni','Chang','Wen','Dong','Ai','Bing','Ang','Zhou','Long','Xian','Kuang','Tiao','Chao','Shi','Huang','Huang','Xuan','Kui','Xu','Jiao','Jin','Zhi','Jin','Shang','Tong','Hong','Yan','Gai','Xiang','Shai','Xiao','Ye','Yun','Hui','Han','Han','Jun','Wan','Xian','Kun','Zhou','Xi','Cheng','Sheng','Bu','Zhe','Zhe','Wu','Wan','Hui','Hao','Chen','Wan','Tian','Zhuo','Zui','Zhou','Pu','Jing','Xi','Shan','Ni','Xi','Qing','Qi','Jing','Gui','Zheng','Yi','Zhi','An','Wan','Lin','Liang','Chang','Wang','Xiao','Zan','Fei','Xuan','Geng','Yi','Xia','Yun','Hui','Xu','Min','Kui','Ye','Ying','Shu','Wei','Shu','Qing','Mao','Nan','Jian','Nuan','An','Yang','Chun','Yao','Suo','Pu','Ming','Jiao','Kai','Gao','Weng','Chang','Qi','Hao','Yan','Li','Ai','Ji','Ji','Men','Zan','Xie','Hao','Mu','Mo','Cong','Ni','Zhang','Hui','Bao','Han','Xuan','Chuan','Liao','Xian','Tan','Jing','Pie','Lin','Tun','Xi','Yi','Ji','Huang','Dai','Ye','Ye','Li','Tan','Tong','Xiao','Fei','Shen','Zhao','Hao','Yi','Xiang','Xing','Shen','Jiao','Bao','Jing','Yan','Ai','Ye','Ru','Shu','Meng','Xun','Yao','Pu','Li','Chen','Kuang','Die','Liao','Yan','Huo','Lu','Xi','Rong','Long','Nang','Luo','Luan','Shai','Tang','Yan','Zhu','Yue','Yue','Qu','Ye','Geng','Ye','Hu','He','Shu','Cao','Cao','Sheng','Man','Ceng','Ceng','Ti')


import importlib

_blocks = {}


def anyascii(string):
    result = []
    for char in string:
        codepoint = ord(char)
        if codepoint <= 0x7f:
            result.append(char)
            continue
        blocknum = codepoint >> 8
        lo = codepoint & 0xff
        try:
            block = _blocks[blocknum]
        except KeyError:
            try:
                block = importlib.import_module('anyascii._data._%03x' % blocknum).b
            except ImportError:
                block = ()
            _blocks[blocknum] = block
        if len(block) > lo:
            result.append(block[lo])
    return ''.join(result)



b=('byum','byub','byubs','byus','byuss','byung','byuj','byuch','byuk','byut','byup','byuh','beu','beug','beukk','beugs','beun','beunj','beunh','beud','beul','beulg','beulm','beulb','beuls','beult','beulp','beulh','beum','beub','beubs','beus','beuss','beung','beuj','beuch','beuk','beut','beup','beuh','bui','buig','buikk','buigs','buin','buinj','buinh','buid','buil','builg','builm','builb','buils','built','builp','builh','buim','buib','buibs','buis','buiss','buing','buij','buich','buik','buit','buip','buih','bi','big','bikk','bigs','bin','binj','binh','bid','bil','bilg','bilm','bilb','bils','bilt','bilp','bilh','bim','bib','bibs','bis','biss','bing','bij','bich','bik','bit','bip','bih','ppa','ppag','ppakk','ppags','ppan','ppanj','ppanh','ppad','ppal','ppalg','ppalm','ppalb','ppals','ppalt','ppalp','ppalh','ppam','ppab','ppabs','ppas','ppass','ppang','ppaj','ppach','ppak','ppat','ppap','ppah','ppae','ppaeg','ppaekk','ppaegs','ppaen','ppaenj','ppaenh','ppaed','ppael','ppaelg','ppaelm','ppaelb','ppaels','ppaelt','ppaelp','ppaelh','ppaem','ppaeb','ppaebs','ppaes','ppaess','ppaeng','ppaej','ppaech','ppaek','ppaet','ppaep','ppaeh','ppya','ppyag','ppyakk','ppyags','ppyan','ppyanj','ppyanh','ppyad','ppyal','ppyalg','ppyalm','ppyalb','ppyals','ppyalt','ppyalp','ppyalh','ppyam','ppyab','ppyabs','ppyas','ppyass','ppyang','ppyaj','ppyach','ppyak','ppyat','ppyap','ppyah','ppyae','ppyaeg','ppyaekk','ppyaegs','ppyaen','ppyaenj','ppyaenh','ppyaed','ppyael','ppyaelg','ppyaelm','ppyaelb','ppyaels','ppyaelt','ppyaelp','ppyaelh','ppyaem','ppyaeb','ppyaebs','ppyaes','ppyaess','ppyaeng','ppyaej','ppyaech','ppyaek','ppyaet','ppyaep','ppyaeh','ppeo','ppeog','ppeokk','ppeogs','ppeon','ppeonj','ppeonh','ppeod','ppeol','ppeolg','ppeolm','ppeolb','ppeols','ppeolt','ppeolp','ppeolh','ppeom','ppeob','ppeobs','ppeos','ppeoss','ppeong','ppeoj','ppeoch','ppeok','ppeot','ppeop','ppeoh','ppe','ppeg','ppekk','ppegs','ppen','ppenj','ppenh','pped','ppel','ppelg','ppelm','ppelb','ppels','ppelt','ppelp','ppelh','ppem','ppeb','ppebs','ppes')


b=('ssal','ssalg','ssalm','ssalb','ssals','ssalt','ssalp','ssalh','ssam','ssab','ssabs','ssas','ssass','ssang','ssaj','ssach','ssak','ssat','ssap','ssah','ssae','ssaeg','ssaekk','ssaegs','ssaen','ssaenj','ssaenh','ssaed','ssael','ssaelg','ssaelm','ssaelb','ssaels','ssaelt','ssaelp','ssaelh','ssaem','ssaeb','ssaebs','ssaes','ssaess','ssaeng','ssaej','ssaech','ssaek','ssaet','ssaep','ssaeh','ssya','ssyag','ssyakk','ssyags','ssyan','ssyanj','ssyanh','ssyad','ssyal','ssyalg','ssyalm','ssyalb','ssyals','ssyalt','ssyalp','ssyalh','ssyam','ssyab','ssyabs','ssyas','ssyass','ssyang','ssyaj','ssyach','ssyak','ssyat','ssyap','ssyah','ssyae','ssyaeg','ssyaekk','ssyaegs','ssyaen','ssyaenj','ssyaenh','ssyaed','ssyael','ssyaelg','ssyaelm','ssyaelb','ssyaels','ssyaelt','ssyaelp','ssyaelh','ssyaem','ssyaeb','ssyaebs','ssyaes','ssyaess','ssyaeng','ssyaej','ssyaech','ssyaek','ssyaet','ssyaep','ssyaeh','sseo','sseog','sseokk','sseogs','sseon','sseonj','sseonh','sseod','sseol','sseolg','sseolm','sseolb','sseols','sseolt','sseolp','sseolh','sseom','sseob','sseobs','sseos','sseoss','sseong','sseoj','sseoch','sseok','sseot','sseop','sseoh','sse','sseg','ssekk','ssegs','ssen','ssenj','ssenh','ssed','ssel','sselg','sselm','sselb','ssels','sselt','sselp','sselh','ssem','sseb','ssebs','sses','ssess','sseng','ssej','ssech','ssek','sset','ssep','sseh','ssyeo','ssyeog','ssyeokk','ssyeogs','ssyeon','ssyeonj','ssyeonh','ssyeod','ssyeol','ssyeolg','ssyeolm','ssyeolb','ssyeols','ssyeolt','ssyeolp','ssyeolh','ssyeom','ssyeob','ssyeobs','ssyeos','ssyeoss','ssyeong','ssyeoj','ssyeoch','ssyeok','ssyeot','ssyeop','ssyeoh','ssye','ssyeg','ssyekk','ssyegs','ssyen','ssyenj','ssyenh','ssyed','ssyel','ssyelg','ssyelm','ssyelb','ssyels','ssyelt','ssyelp','ssyelh','ssyem','ssyeb','ssyebs','ssyes','ssyess','ssyeng','ssyej','ssyech','ssyek','ssyet','ssyep','ssyeh','sso','ssog','ssokk','ssogs','sson','ssonj','ssonh','ssod','ssol','ssolg','ssolm','ssolb','ssols','ssolt','ssolp','ssolh','ssom','ssob','ssobs','ssos','ssoss','ssong','ssoj','ssoch','ssok','ssot','ssop','ssoh','sswa','sswag','sswakk','sswags','sswan','sswanj','sswanh','sswad','sswal','sswalg','sswalm','sswalb')


b=('luk','lut','lup','luh','lwo','lwog','lwokk','lwogs','lwon','lwonj','lwonh','lwod','lwol','lwolg','lwolm','lwolb','lwols','lwolt','lwolp','lwolh','lwom','lwob','lwobs','lwos','lwoss','lwong','lwoj','lwoch','lwok','lwot','lwop','lwoh','lwe','lweg','lwekk','lwegs','lwen','lwenj','lwenh','lwed','lwel','lwelg','lwelm','lwelb','lwels','lwelt','lwelp','lwelh','lwem','lweb','lwebs','lwes','lwess','lweng','lwej','lwech','lwek','lwet','lwep','lweh','lwi','lwig','lwikk','lwigs','lwin','lwinj','lwinh','lwid','lwil','lwilg','lwilm','lwilb','lwils','lwilt','lwilp','lwilh','lwim','lwib','lwibs','lwis','lwiss','lwing','lwij','lwich','lwik','lwit','lwip','lwih','lyu','lyug','lyukk','lyugs','lyun','lyunj','lyunh','lyud','lyul','lyulg','lyulm','lyulb','lyuls','lyult','lyulp','lyulh','lyum','lyub','lyubs','lyus','lyuss','lyung','lyuj','lyuch','lyuk','lyut','lyup','lyuh','leu','leug','leukk','leugs','leun','leunj','leunh','leud','leul','leulg','leulm','leulb','leuls','leult','leulp','leulh','leum','leub','leubs','leus','leuss','leung','leuj','leuch','leuk','leut','leup','leuh','lui','luig','luikk','luigs','luin','luinj','luinh','luid','luil','luilg','luilm','luilb','luils','luilt','luilp','luilh','luim','luib','luibs','luis','luiss','luing','luij','luich','luik','luit','luip','luih','li','lig','likk','ligs','lin','linj','linh','lid','lil','lilg','lilm','lilb','lils','lilt','lilp','lilh','lim','lib','libs','lis','liss','ling','lij','lich','lik','lit','lip','lih','ma','mag','makk','mags','man','manj','manh','mad','mal','malg','malm','malb','mals','malt','malp','malh','mam','mab','mabs','mas','mass','mang','maj','mach','mak','mat','map','mah','mae','maeg','maekk','maegs','maen','maenj','maenh','maed','mael','maelg','maelm','maelb','maels','maelt','maelp','maelh','maem','maeb','maebs','maes','maess','maeng','maej','maech','maek','maet','maep','maeh')


b=('Xia','Yuan','Zong','Xu','Sheng','Wei','Geng','Xuan','Ying','Jin','Yi','Zhui','Ni','Bang','Gu','Pan','Zhou','Jian','Ci','Quan','Shuang','Yun','Xia','Cui','Xi','Rong','Tao','Fu','Yun','Chen','Gao','Ru','Hu','Zai','Teng','Xian','Su','Zhen','Zong','Tao','Huang','Cai','Bi','Feng','Cu','Li','Suo','Yan','Xi','Zong','Lei','Juan','Qian','Man','Zhi','Lu','Mu','Piao','Lian','Mi','Xuan','Zong','Ji','Shan','Sui','Fan','Lu','Beng','Yi','Sao','Mou','Yao','Qiang','Hun','Xian','Ji','Sha','Xiu','Ran','Xuan','Sui','Qiao','Zeng','Zuo','Zhi','Shan','San','Lin','Yu','Fan','Liao','Chuo','Zun','Jian','Rao','Chan','Rui','Xiu','Hui','Hua','Zuan','Xi','Qiang','Yun','Da','Sheng','Hui','Xi','Se','Jian','Jiang','Huan','Zao','Cong','Xie','Jiao','Bi','Dan','Yi','Nong','Sui','Yi','Shai','Xu','Ji','Bin','Qian','Lan','Pu','Xun','Zuan','Qi','Peng','Yao','Mo','Lei','Xie','Zuan','Kuang','You','Xu','Lei','Xian','Chan','Jiao','Lu','Chan','Ying','Cai','Rang','Xian','Zui','Zuan','Luo','Li','Dao','Lan','Lei','Lian','Si','Jiu','Yu','Hong','Zhou','Xian','Ge','Yue','Ji','Wan','Kuang','Ji','Ren','Wei','Yun','Hong','Chun','Pi','Sha','Gang','Na','Ren','Zong','Lun','Fen','Zhi','Wen','Fang','Zhu','Zhen','Niu','Shu','Xian','Gan','Xie','Fu','Lian','Zu','Shen','Xi','Zhi','Zhong','Zhou','Ban','Fu','Chu','Shao','Yi','Jing','Dai','Bang','Rong','Jie','Ku','Rao','Die','Hang','Hui','Gei','Xuan','Jiang','Luo','Jue','Jiao','Tong','Geng','Xiao','Juan','Xiu','Xi','Sui','Tao','Ji','Ti','Ji','Xu','Ling','Ying','Xu','Qi','Fei','Chuo','Shang','Gun','Sheng','Wei','Mian','Shou','Beng','Chou','Tao','Liu','Quan','Zong','Zhan','Wan','Lu')


b=('ttyels','ttyelt','ttyelp','ttyelh','ttyem','ttyeb','ttyebs','ttyes','ttyess','ttyeng','ttyej','ttyech','ttyek','ttyet','ttyep','ttyeh','tto','ttog','ttokk','ttogs','tton','ttonj','ttonh','ttod','ttol','ttolg','ttolm','ttolb','ttols','ttolt','ttolp','ttolh','ttom','ttob','ttobs','ttos','ttoss','ttong','ttoj','ttoch','ttok','ttot','ttop','ttoh','ttwa','ttwag','ttwakk','ttwags','ttwan','ttwanj','ttwanh','ttwad','ttwal','ttwalg','ttwalm','ttwalb','ttwals','ttwalt','ttwalp','ttwalh','ttwam','ttwab','ttwabs','ttwas','ttwass','ttwang','ttwaj','ttwach','ttwak','ttwat','ttwap','ttwah','ttwae','ttwaeg','ttwaekk','ttwaegs','ttwaen','ttwaenj','ttwaenh','ttwaed','ttwael','ttwaelg','ttwaelm','ttwaelb','ttwaels','ttwaelt','ttwaelp','ttwaelh','ttwaem','ttwaeb','ttwaebs','ttwaes','ttwaess','ttwaeng','ttwaej','ttwaech','ttwaek','ttwaet','ttwaep','ttwaeh','ttoe','ttoeg','ttoekk','ttoegs','ttoen','ttoenj','ttoenh','ttoed','ttoel','ttoelg','ttoelm','ttoelb','ttoels','ttoelt','ttoelp','ttoelh','ttoem','ttoeb','ttoebs','ttoes','ttoess','ttoeng','ttoej','ttoech','ttoek','ttoet','ttoep','ttoeh','ttyo','ttyog','ttyokk','ttyogs','ttyon','ttyonj','ttyonh','ttyod','ttyol','ttyolg','ttyolm','ttyolb','ttyols','ttyolt','ttyolp','ttyolh','ttyom','ttyob','ttyobs','ttyos','ttyoss','ttyong','ttyoj','ttyoch','ttyok','ttyot','ttyop','ttyoh','ttu','ttug','ttukk','ttugs','ttun','ttunj','ttunh','ttud','ttul','ttulg','ttulm','ttulb','ttuls','ttult','ttulp','ttulh','ttum','ttub','ttubs','ttus','ttuss','ttung','ttuj','ttuch','ttuk','ttut','ttup','ttuh','ttwo','ttwog','ttwokk','ttwogs','ttwon','ttwonj','ttwonh','ttwod','ttwol','ttwolg','ttwolm','ttwolb','ttwols','ttwolt','ttwolp','ttwolh','ttwom','ttwob','ttwobs','ttwos','ttwoss','ttwong','ttwoj','ttwoch','ttwok','ttwot','ttwop','ttwoh','ttwe','ttweg','ttwekk','ttwegs','ttwen','ttwenj','ttwenh','ttwed','ttwel','ttwelg','ttwelm','ttwelb','ttwels','ttwelt','ttwelp','ttwelh','ttwem','ttweb','ttwebs','ttwes','ttwess','ttweng','ttwej','ttwech','ttwek','ttwet','ttwep','ttweh','ttwi','ttwig','ttwikk','ttwigs','ttwin','ttwinj','ttwinh','ttwid','ttwil','ttwilg','ttwilm','ttwilb','ttwils','ttwilt','ttwilp','ttwilh')


b=('kax','ka','kap','kuox','kuo','kuop','kot','kox','ko','kop','ket','kex','ke','kep','kut','kux','ku','kup','kurx','kur','ggit','ggix','ggi','ggiex','ggie','ggiep','ggat','ggax','gga','ggap','gguot','gguox','gguo','gguop','ggot','ggox','ggo','ggop','gget','ggex','gge','ggep','ggut','ggux','ggu','ggup','ggurx','ggur','mgiex','mgie','mgat','mgax','mga','mgap','mguox','mguo','mguop','mgot','mgox','mgo','mgop','mgex','mge','mgep','mgut','mgux','mgu','mgup','mgurx','mgur','hxit','hxix','hxi','hxip','hxiet','hxiex','hxie','hxiep','hxat','hxax','hxa','hxap','hxuot','hxuox','hxuo','hxuop','hxot','hxox','hxo','hxop','hxex','hxe','hxep','ngiex','ngie','ngiep','ngat','ngax','nga','ngap','nguot','nguox','nguo','ngot','ngox','ngo','ngop','ngex','nge','ngep','hit','hiex','hie','hat','hax','ha','hap','huot','huox','huo','huop','hot','hox','ho','hop','hex','he','hep','wat','wax','wa','wap','wuox','wuo','wuop','wox','wo','wop','wex','we','wep','zit','zix','zi','zip','ziex','zie','ziep','zat','zax','za','zap','zuox','zuo','zuop','zot','zox','zo','zop','zex','ze','zep','zut','zux','zu','zup','zurx','zur','zyt','zyx','zy','zyp','zyrx','zyr','cit','cix','ci','cip','ciet','ciex','cie','ciep','cat','cax','ca','cap','cuox','cuo','cuop','cot','cox','co','cop','cex','ce','cep','cut','cux','cu','cup','curx','cur','cyt','cyx','cy','cyp','cyrx','cyr','zzit','zzix','zzi','zzip','zziet','zziex','zzie','zziep','zzat','zzax','zza','zzap','zzox','zzo','zzop','zzex','zze','zzep','zzux','zzu','zzup','zzurx','zzur','zzyt','zzyx','zzy','zzyp','zzyrx','zzyr','nzit','nzix','nzi','nzip','nziex','nzie','nziep','nzat','nzax','nza','nzap','nzuox','nzuo','nzox','nzop','nzex','nze','nzux','nzu')


b=('Za','Bi','Shi','Bu','Ding','Shuai','Fan','Nie','Shi','Fen','Pa','Zhi','Xi','Hu','Dan','Wei','Zhang','Tang','Dai','Mo','Pei','Pa','Tie','Bo','Lian','Zhi','Zhou','Bo','Zhi','Di','Mo','Yi','Yi','Ping','Qia','Juan','Ru','Shuai','Dai','Zheng','Shui','Qiao','Zhen','Shi','Qun','Xi','Bang','Dai','Gui','Chou','Ping','Zhang','San','Wan','Dai','Wei','Chang','Sha','Qi','Ze','Guo','Mao','Du','Hou','Zheng','Xu','Mi','Wei','Wo','Fu','Yi','Bang','Ping','Die','Gong','Pan','Huang','Tao','Mi','Jia','Teng','Hui','Zhong','Shan','Man','Mu','Biao','Guo','Ze','Mu','Bang','Zhang','Jing','Chan','Fu','Zhi','Hu','Fan','Chuang','Bi','Bi','Zhang','Mi','Qiao','Chan','Fen','Meng','Bang','Chou','Mie','Chu','Jie','Xian','Lan','Gan','Ping','Nian','Jian','Bing','Bing','Xing','Gan','Yao','Huan','You','You','Ji','Guang','Pi','Ting','Ze','Guang','Zhuang','Mo','Qing','Bi','Qin','Dun','Chuang','Gui','Ya','Bai','Jie','Xu','Lu','Wu','Zhuang','Ku','Ying','Di','Pao','Dian','Ya','Miao','Geng','Ci','Fu','Tong','Pang','Fei','Xiang','Yi','Zhi','Tiao','Zhi','Xiu','Du','Zuo','Xiao','Tu','Gui','Ku','Mang','Ting','You','Bu','Bing','Cheng','Lai','Bi','Ji','An','Shu','Kang','Yong','Tuo','Song','Shu','Qing','Yu','Yu','Miao','Sou','Ce','Xiang','Fei','Jiu','E','Gui','Liu','Sha','Lian','Lang','Sou','Zhi','Bu','Qing','Jiu','Jiu','Jin','Ao','Kuo','Lou','Yin','Liao','Dai','Lu','Yi','Chu','Chan','Tu','Si','Xin','Miao','Chang','Wu','Fei','Guang','Ku','Kuai','Bi','Qiang','Xie','Lin','Lin','Liao','Lu','Ji','Ying','Xian','Ting','Yong','Li','Ting','Yin','Xun','Yan','Ting','Di','Pai','Jian','Hui','Nai','Hui','Gong','Nian')


b=('ttwim','ttwib','ttwibs','ttwis','ttwiss','ttwing','ttwij','ttwich','ttwik','ttwit','ttwip','ttwih','ttyu','ttyug','ttyukk','ttyugs','ttyun','ttyunj','ttyunh','ttyud','ttyul','ttyulg','ttyulm','ttyulb','ttyuls','ttyult','ttyulp','ttyulh','ttyum','ttyub','ttyubs','ttyus','ttyuss','ttyung','ttyuj','ttyuch','ttyuk','ttyut','ttyup','ttyuh','tteu','tteug','tteukk','tteugs','tteun','tteunj','tteunh','tteud','tteul','tteulg','tteulm','tteulb','tteuls','tteult','tteulp','tteulh','tteum','tteub','tteubs','tteus','tteuss','tteung','tteuj','tteuch','tteuk','tteut','tteup','tteuh','ttui','ttuig','ttuikk','ttuigs','ttuin','ttuinj','ttuinh','ttuid','ttuil','ttuilg','ttuilm','ttuilb','ttuils','ttuilt','ttuilp','ttuilh','ttuim','ttuib','ttuibs','ttuis','ttuiss','ttuing','ttuij','ttuich','ttuik','ttuit','ttuip','ttuih','tti','ttig','ttikk','ttigs','ttin','ttinj','ttinh','ttid','ttil','ttilg','ttilm','ttilb','ttils','ttilt','ttilp','ttilh','ttim','ttib','ttibs','ttis','ttiss','tting','ttij','ttich','ttik','ttit','ttip','ttih','la','lag','lakk','lags','lan','lanj','lanh','lad','lal','lalg','lalm','lalb','lals','lalt','lalp','lalh','lam','lab','labs','las','lass','lang','laj','lach','lak','lat','lap','lah','lae','laeg','laekk','laegs','laen','laenj','laenh','laed','lael','laelg','laelm','laelb','laels','laelt','laelp','laelh','laem','laeb','laebs','laes','laess','laeng','laej','laech','laek','laet','laep','laeh','lya','lyag','lyakk','lyags','lyan','lyanj','lyanh','lyad','lyal','lyalg','lyalm','lyalb','lyals','lyalt','lyalp','lyalh','lyam','lyab','lyabs','lyas','lyass','lyang','lyaj','lyach','lyak','lyat','lyap','lyah','lyae','lyaeg','lyaekk','lyaegs','lyaen','lyaenj','lyaenh','lyaed','lyael','lyaelg','lyaelm','lyaelb','lyaels','lyaelt','lyaelp','lyaelh','lyaem','lyaeb','lyaebs','lyaes','lyaess','lyaeng','lyaej','lyaech','lyaek','lyaet','lyaep','lyaeh','leo','leog','leokk','leogs','leon','leonj','leonh','leod','leol','leolg','leolm','leolb','leols','leolt','leolp','leolh','leom','leob','leobs','leos')


b=('Qing','Yu','Piao','Ji','Ya','Chao','Qi','Xi','Ji','Lu','Lou','Long','Jin','Guo','Cong','Lou','Zhi','Gai','Qiang','Li','Yan','Cao','Jiao','Cong','Chun','Tuan','Ou','Teng','Ye','Xi','Mi','Tang','Mo','Shang','Han','Lian','Lan','Wa','Chi','Gan','Feng','Xuan','Yi','Man','Zi','Mang','Kang','Luo','Peng','Shu','Zhang','Zhang','Zhuang','Xu','Huan','Huo','Jian','Yan','Shuang','Liao','Cui','Ti','Yang','Jiang','Cong','Ying','Hong','Xiu','Shu','Guan','Ying','Xiao','Zong','Kun','Xu','Lian','Zhi','Wei','Pi','Yu','Jiao','Po','Dang','Hui','Jie','Wu','Pa','Ji','Pan','Wei','Su','Qian','Qian','Xi','Lu','Xi','Xun','Dun','Huang','Min','Run','Su','Lao','Zhen','Cong','Yi','Zhe','Wan','Shan','Tan','Chao','Xun','Kui','Ye','Shao','Tu','Zhu','Sa','Hei','Bi','Shan','Chan','Chan','Shu','Tong','Pu','Lin','Wei','Se','Se','Cheng','Jiong','Cheng','Hua','Jiao','Lao','Che','Gan','Cun','Hong','Si','Shu','Peng','Han','Yun','Liu','Hong','Fu','Hao','He','Xian','Jian','Shan','Xi','Yu','Lu','Lan','Ning','Yu','Lin','Mian','Zao','Dang','Huan','Ze','Xie','Yu','Li','Shi','Xue','Ling','Wan','Zi','Yong','Hui','Can','Lian','Dian','Ye','Ao','Huan','Zhen','Chan','Man','Dan','Dan','Yi','Sui','Pi','Ju','Ta','Qin','Ji','Zhuo','Lian','Nong','Guo','Jin','Fen','Se','Ji','Sui','Hui','Chu','Ta','Song','Ding','Se','Zhu','Lai','Bin','Lian','Mi','Shi','Shu','Mi','Ning','Ying','Ying','Meng','Jin','Qi','Bi','Ji','Hao','Ru','Cui','Wo','Tao','Yin','Yin','Dui','Ci','Huo','Qing','Lan','Jun','Ai','Pu','Zhuo','Wei','Bin','Gu','Qian','Ying','Bin','Kuo','Fei','Cang','Me','Jian','Wei','Luo','Zan','Lu','Li')


b=('Yu','Shei','Shen','Diao','Chan','Liang','Zhun','Sui','Tan','Shen','Yi','Mou','Chen','Die','Huang','Jian','Xie','Xue','Ye','Wei','E','Yu','Xuan','Chan','Zi','An','Yan','Di','Mi','Pian','Xu','Mo','Dang','Su','Xie','Yao','Bang','Shi','Qian','Mi','Jin','Man','Zhe','Jian','Miu','Tan','Zen','Qiao','Lan','Pu','Jue','Yan','Qian','Zhan','Chen','Gu','Qian','Hong','Xia','Ji','Hong','Han','Hong','Xi','Xi','Huo','Liao','Han','Du','Long','Dou','Jiang','Qi','Shi','Li','Deng','Wan','Bi','Shu','Xian','Feng','Zhi','Zhi','Yan','Yan','Shi','Chu','Hui','Tun','Yi','Tun','Yi','Jian','Ba','Hou','E','Chu','Xiang','Huan','Jian','Ken','Gai','Ju','Fu','Xi','Bin','Hao','Yu','Zhu','Jia','Fen','Xi','Bo','Wen','Huan','Bin','Di','Zong','Fen','Yi','Zhi','Bao','Chai','An','Pi','Na','Pi','Gou','Na','You','Diao','Mo','Si','Xiu','Huan','Kun','He','Hao','Mo','An','Mao','Li','Ni','Bi','Yu','Jia','Tuan','Mao','Pi','Xi','Yi','Ju','Mo','Chu','Tan','Huan','Jue','Bei','Zhen','Yuan','Fu','Cai','Gong','Te','Yi','Hang','Wan','Pin','Huo','Fan','Tan','Guan','Ze','Zhi','Er','Zhu','Shi','Bi','Zi','Er','Gui','Pian','Bian','Mai','Dai','Sheng','Kuang','Fei','Tie','Yi','Chi','Mao','He','Bi','Lu','Lin','Hui','Gai','Pian','Zi','Jia','Xu','Zei','Jiao','Gai','Zang','Jian','Ying','Xun','Zhen','She','Bin','Bin','Qiu','She','Chuan','Zang','Zhou','Lai','Zan','Ci','Chen','Shang','Tian','Pei','Geng','Xian','Mai','Jian','Sui','Fu','Tan','Cong','Cong','Zhi','Ji','Zhang','Du','Jin','Xiong','Chun','Yun','Bao','Zai','Lai','Feng','Cang','Ji','Sheng','Yi','Zhuan','Fu','Gou','Sai','Ze','Liao')


b=('Mou','Ye','Wei','Xing','Teng','Zhou','Shan','Jian','Po','Kui','Huang','Huo','Ge','Ying','Mi','Xiao','Mi','Xi','Qiang','Chen','Xue','Ti','Su','Bang','Chi','Qian','Shi','Jiang','Yuan','Xie','He','Tao','Yao','Yao','Lu','Yu','Biao','Cong','Qing','Li','Mo','Mo','Shang','Zhe','Miu','Jian','Ze','Jie','Lian','Lou','Can','Ou','Gun','Xi','Zhuo','Ao','Ao','Jin','Zhe','Yi','Hu','Jiang','Man','Chao','Han','Hua','Chan','Xu','Zeng','Se','Xi','Zha','Dui','Zheng','Nao','Lan','E','Ying','Jue','Ji','Zun','Jiao','Bo','Hui','Zhuan','Wu','Zen','Zha','Shi','Qiao','Tan','Zen','Pu','Sheng','Xuan','Zao','Tan','Dang','Sui','Xian','Ji','Jiao','Jing','Zhan','Nang','Yi','Ai','Zhan','Pi','Hui','Hua','Yi','Yi','Shan','Rang','Nou','Qian','Dui','Ta','Hu','Zhou','Hao','Ai','Ying','Jian','Yu','Jian','Hui','Du','Zhe','Xuan','Zan','Lei','Shen','Wei','Chan','Li','Yi','Bian','Zhe','Yan','E','Chou','Wei','Chou','Yao','Chan','Rang','Yin','Lan','Chen','Xie','Nie','Huan','Zan','Yi','Dang','Zhan','Yan','Du','Yan','Ji','Ding','Fu','Ren','Ji','Jie','Hong','Tao','Rang','Shan','Qi','Tuo','Xun','Yi','Xun','Ji','Ren','Jiang','Hui','Ou','Ju','Ya','Ne','Xu','E','Lun','Xiong','Song','Feng','She','Fang','Jue','Zheng','Gu','He','Ping','Zu','Shi','Xiong','Zha','Su','Zhen','Di','Zhou','Ci','Qu','Zhao','Bi','Yi','Yi','Kuang','Lei','Shi','Gua','Shi','Ji','Hui','Cheng','Zhu','Shen','Hua','Dan','Gou','Quan','Gui','Xun','Yi','Zheng','Gai','Xiang','Cha','Hun','Xu','Zhou','Jie','Wu','Yu','Qiao','Wu','Gao','You','Hui','Kuang','Shuo','Song','Ei','Qing','Zhu','Zou','Nuo','Du','Zhuo','Fei','Ke','Wei')


b=('Yi','Bai','Chen','Wan','Zhi','Zhui','Biao','Yun','Zeng','Dan','Zan','Yan','Pu','Shan','Wan','Ying','Jin','Gan','Xian','Zang','Bi','Du','Shu','Yan','Shang','Xuan','Long','Gan','Zang','Bei','Zhen','Fu','Yuan','Gong','Cai','Ze','Xian','Bai','Zhang','Huo','Zhi','Fan','Tan','Pin','Bian','Gou','Zhu','Guan','Er','Jian','Ben','Shi','Tie','Gui','Kuang','Dai','Mao','Fei','He','Yi','Zei','Zhi','Jia','Hui','Zi','Lin','Lu','Zang','Zi','Gai','Jin','Qiu','Zhen','Lai','She','Fu','Du','Ji','Shu','Shang','Ci','Bi','Zhou','Geng','Pei','Dan','Lai','Feng','Zhui','Fu','Zhuan','Sai','Ze','Yan','Zan','Yun','Zeng','Shan','Ying','Gan','Chi','Xi','She','Nan','Tong','Xi','Cheng','He','Cheng','Zhe','Xia','Tang','Zou','Zou','Li','Jiu','Fu','Zhao','Gan','Qi','Shan','Qiong','Yin','Xian','Zi','Jue','Qin','Chi','Ci','Chen','Chen','Die','Ju','Chao','Di','Xi','Zhan','Jue','Yue','Qu','Ji','Chi','Chu','Gua','Xue','Zi','Tiao','Duo','Lie','Gan','Suo','Cu','Xi','Zhao','Su','Yin','Ju','Jian','Que','Tang','Chuo','Cui','Lu','Qu','Dang','Qiu','Zi','Ti','Qu','Chi','Huang','Qiao','Qiao','Jiao','Zao','Ti','Er','Zan','Zan','Zu','Pa','Bao','Ku','Ke','Dun','Jue','Fu','Chen','Jian','Fang','Zhi','Ta','Yue','Ba','Qi','Yue','Qiang','Tuo','Tai','Yi','Nian','Ling','Mei','Ba','Die','Ku','Tuo','Jia','Ci','Pao','Qia','Zhu','Ju','Dian','Zhi','Fu','Pan','Ju','Shan','Bo','Ni','Ju','Li','Gen','Yi','Ji','Duo','Xian','Jiao','Duo','Zhu','Quan','Kua','Zhuai','Gui','Qiong','Kui','Xiang','Chi','Lu','Pian','Zhi','Jia','Tiao','Cai','Jian','Da','Qiao','Bi','Xian','Duo','Ji','Ju','Ji','Shu','Tu')


b=('Gae','Gaeng','Geo','Go','Gol','Gwan','Gwi','Gau','Gyun','Geul','Geum','Na','Na','Na','Na','Na','Na','Na','Na','Na','Nag','Nag','Nag','Nag','Nag','Nag','Nag','Nan','Nan','Nan','Nan','Nan','Nan','Nam','Nam','Nam','Nam','Nab','Nab','Nab','Long','Nang','Nang','Nang','Nang','Nae','Naeng','No','No','No','No','No','No','No','Lou','No','No','No','No','Nog','Nog','Nog','Nog','Nog','Nog','Non','Nong','Nong','Nong','Nong','Noe','Noe','Noe','Noe','Nu','Nu','Nu','Nu','Nu','Nu','Nu','Nu','Neug','Neug','Neum','Neung','Neung','Neung','Neung','Neung','Du','La','Lag','Lag','Lan','Lyeong','Lo','Lyul','Li','Bae','Beon','Byeon','Bu','Bul','Bi','Sag','Sag','Sam','Saeg','Saeng','Seob','Se','Swae','Sin','Sim','Sib','Ya','Yag','Yag','Yang','Yang','Yang','Yang','Yang','Yang','Yang','Yang','Yeo','Yeo','Yeo','Yeo','Yeo','Yeo','Yeo','Yeo','Yeo','Yeo','Yeo','Yeog','Yeog','Yeog','Yeog','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeol','Yeol','Yeol','Yeol','Yeol','Yeol','Yeom','Yeom','Yeom','Yeom','Yeom','Yeob','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Ye','Ye','Ye','Ye','O','Yo','Yo','Yo','Yo','Yo','Yo','Yo','Yo','Yo','Yo','Yong','Un','Won','Yu','Yu','Yu','Yu','Yu','Yu','Yu','Yu','Yu','Yu','Yug','Yug','Yug','Yun','Yun','Yun','Yun','Yul','Yul','Yul','Yul','Yung','I','I','I','I','I','I','I','I','I','I','I','I','I','I','Ig','Ig','In','In','In','In','In','In','In','Im','Im','Im','Ib','Ib','Ib','Jang','Jeog','Ji','Jib','Cha','Cheog')


b=('Ben','Yuan','Wen','Ruo','Fei','Qing','Yuan','Ke','Ji','She','Yuan','Se','Lu','Zi','Du','Yi','Jian','Mian','Pai','Xi','Yu','Yuan','Shen','Shen','Rou','Huan','Zhu','Jian','Nuan','Yu','Qiu','Ting','Qu','Du','Fan','Zha','Bo','Wo','Wo','Di','Wei','Wen','Ru','Xie','Ce','Wei','He','Gang','Yan','Hong','Xuan','Mi','Ke','Mao','Ying','Yan','You','Hong','Miao','Sheng','Mei','Zai','Hun','Nai','Gui','Chi','E','Pai','Mei','Lian','Qi','Qi','Mei','Tian','Cou','Wei','Can','Tuan','Mian','Hui','Mo','Xu','Ji','Pen','Jian','Jian','Hu','Feng','Xiang','Yi','Yin','Zhan','Shi','Jie','Cheng','Huang','Tan','Yu','Bi','Min','Shi','Tu','Sheng','Yong','Ju','Dong','Tuan','Jiao','Jiao','Qiu','Yan','Tang','Long','Huo','Yuan','Nan','Ban','You','Quan','Zhuang','Liang','Chan','Xian','Chun','Nie','Zi','Wan','Shi','Man','Ying','La','Kui','Feng','Jian','Xu','Lou','Wei','Gai','Bo','Ying','Po','Jin','Yan','Tang','Yuan','Suo','Yuan','Lian','Yao','Meng','Zhun','Cheng','Ke','Tai','Ta','Wa','Liu','Gou','Sao','Ming','Zha','Shi','Yi','Lun','Ma','Pu','Wei','Li','Zai','Wu','Xi','Wen','Qiang','Ze','Shi','Su','Ai','Qin','Sou','Yun','Xiu','Yin','Rong','Hun','Su','Suo','Ni','Ta','Shi','Ru','Ai','Pan','Chu','Chu','Pang','Weng','Cang','Mie','Ge','Dian','Hao','Huang','Xi','Zi','Di','Zhi','Xing','Fu','Jie','Hua','Ge','Zi','Tao','Teng','Sui','Bi','Jiao','Hui','Gun','Yin','Gao','Long','Zhi','Yan','She','Man','Ying','Chun','Lu','Lan','Luan','Yao','Bin','Tan','Yu','Xiu','Hu','Bi','Biao','Zhi','Jiang','Kou','Shen','Shang','Di','Mi','Ao','Lu','Hu','Hu','You','Chan','Fan','Yong','Gun','Man')


b=('mya','myag','myakk','myags','myan','myanj','myanh','myad','myal','myalg','myalm','myalb','myals','myalt','myalp','myalh','myam','myab','myabs','myas','myass','myang','myaj','myach','myak','myat','myap','myah','myae','myaeg','myaekk','myaegs','myaen','myaenj','myaenh','myaed','myael','myaelg','myaelm','myaelb','myaels','myaelt','myaelp','myaelh','myaem','myaeb','myaebs','myaes','myaess','myaeng','myaej','myaech','myaek','myaet','myaep','myaeh','meo','meog','meokk','meogs','meon','meonj','meonh','meod','meol','meolg','meolm','meolb','meols','meolt','meolp','meolh','meom','meob','meobs','meos','meoss','meong','meoj','meoch','meok','meot','meop','meoh','me','meg','mekk','megs','men','menj','menh','med','mel','melg','melm','melb','mels','melt','melp','melh','mem','meb','mebs','mes','mess','meng','mej','mech','mek','met','mep','meh','myeo','myeog','myeokk','myeogs','myeon','myeonj','myeonh','myeod','myeol','myeolg','myeolm','myeolb','myeols','myeolt','myeolp','myeolh','myeom','myeob','myeobs','myeos','myeoss','myeong','myeoj','myeoch','myeok','myeot','myeop','myeoh','mye','myeg','myekk','myegs','myen','myenj','myenh','myed','myel','myelg','myelm','myelb','myels','myelt','myelp','myelh','myem','myeb','myebs','myes','myess','myeng','myej','myech','myek','myet','myep','myeh','mo','mog','mokk','mogs','mon','monj','monh','mod','mol','molg','molm','molb','mols','molt','molp','molh','mom','mob','mobs','mos','moss','mong','moj','moch','mok','mot','mop','moh','mwa','mwag','mwakk','mwags','mwan','mwanj','mwanh','mwad','mwal','mwalg','mwalm','mwalb','mwals','mwalt','mwalp','mwalh','mwam','mwab','mwabs','mwas','mwass','mwang','mwaj','mwach','mwak','mwat','mwap','mwah','mwae','mwaeg','mwaekk','mwaegs','mwaen','mwaenj','mwaenh','mwaed','mwael','mwaelg','mwaelm','mwaelb','mwaels','mwaelt','mwaelp','mwaelh','mwaem','mwaeb','mwaebs','mwaes','mwaess','mwaeng','mwaej','mwaech','mwaek','mwaet','mwaep','mwaeh','moe','moeg','moekk','moegs')


b=('bols','bolt','bolp','bolh','bom','bob','bobs','bos','boss','bong','boj','boch','bok','bot','bop','boh','bwa','bwag','bwakk','bwags','bwan','bwanj','bwanh','bwad','bwal','bwalg','bwalm','bwalb','bwals','bwalt','bwalp','bwalh','bwam','bwab','bwabs','bwas','bwass','bwang','bwaj','bwach','bwak','bwat','bwap','bwah','bwae','bwaeg','bwaekk','bwaegs','bwaen','bwaenj','bwaenh','bwaed','bwael','bwaelg','bwaelm','bwaelb','bwaels','bwaelt','bwaelp','bwaelh','bwaem','bwaeb','bwaebs','bwaes','bwaess','bwaeng','bwaej','bwaech','bwaek','bwaet','bwaep','bwaeh','boe','boeg','boekk','boegs','boen','boenj','boenh','boed','boel','boelg','boelm','boelb','boels','boelt','boelp','boelh','boem','boeb','boebs','boes','boess','boeng','boej','boech','boek','boet','boep','boeh','byo','byog','byokk','byogs','byon','byonj','byonh','byod','byol','byolg','byolm','byolb','byols','byolt','byolp','byolh','byom','byob','byobs','byos','byoss','byong','byoj','byoch','byok','byot','byop','byoh','bu','bug','bukk','bugs','bun','bunj','bunh','bud','bul','bulg','bulm','bulb','buls','bult','bulp','bulh','bum','bub','bubs','bus','buss','bung','buj','buch','buk','but','bup','buh','bwo','bwog','bwokk','bwogs','bwon','bwonj','bwonh','bwod','bwol','bwolg','bwolm','bwolb','bwols','bwolt','bwolp','bwolh','bwom','bwob','bwobs','bwos','bwoss','bwong','bwoj','bwoch','bwok','bwot','bwop','bwoh','bwe','bweg','bwekk','bwegs','bwen','bwenj','bwenh','bwed','bwel','bwelg','bwelm','bwelb','bwels','bwelt','bwelp','bwelh','bwem','bweb','bwebs','bwes','bwess','bweng','bwej','bwech','bwek','bwet','bwep','bweh','bwi','bwig','bwikk','bwigs','bwin','bwinj','bwinh','bwid','bwil','bwilg','bwilm','bwilb','bwils','bwilt','bwilp','bwilh','bwim','bwib','bwibs','bwis','bwiss','bwing','bwij','bwich','bwik','bwit','bwip','bwih','byu','byug','byukk','byugs','byun','byunj','byunh','byud','byul','byulg','byulm','byulb','byuls','byult','byulp','byulh')


b=('wek','wet','wep','weh','wi','wig','wikk','wigs','win','winj','winh','wid','wil','wilg','wilm','wilb','wils','wilt','wilp','wilh','wim','wib','wibs','wis','wiss','wing','wij','wich','wik','wit','wip','wih','yu','yug','yukk','yugs','yun','yunj','yunh','yud','yul','yulg','yulm','yulb','yuls','yult','yulp','yulh','yum','yub','yubs','yus','yuss','yung','yuj','yuch','yuk','yut','yup','yuh','eu','eug','eukk','eugs','eun','eunj','eunh','eud','eul','eulg','eulm','eulb','euls','eult','eulp','eulh','eum','eub','eubs','eus','euss','eung','euj','euch','euk','eut','eup','euh','ui','uig','uikk','uigs','uin','uinj','uinh','uid','uil','uilg','uilm','uilb','uils','uilt','uilp','uilh','uim','uib','uibs','uis','uiss','uing','uij','uich','uik','uit','uip','uih','i','ig','ikk','igs','in','inj','inh','id','il','ilg','ilm','ilb','ils','ilt','ilp','ilh','im','ib','ibs','is','iss','ing','ij','ich','ik','it','ip','ih','ja','jag','jakk','jags','jan','janj','janh','jad','jal','jalg','jalm','jalb','jals','jalt','jalp','jalh','jam','jab','jabs','jas','jass','jang','jaj','jach','jak','jat','jap','jah','jae','jaeg','jaekk','jaegs','jaen','jaenj','jaenh','jaed','jael','jaelg','jaelm','jaelb','jaels','jaelt','jaelp','jaelh','jaem','jaeb','jaebs','jaes','jaess','jaeng','jaej','jaech','jaek','jaet','jaep','jaeh','jya','jyag','jyakk','jyags','jyan','jyanj','jyanh','jyad','jyal','jyalg','jyalm','jyalb','jyals','jyalt','jyalp','jyalh','jyam','jyab','jyabs','jyas','jyass','jyang','jyaj','jyach','jyak','jyat','jyap','jyah','jyae','jyaeg','jyaekk','jyaegs','jyaen','jyaenj','jyaenh','jyaed','jyael','jyaelg','jyaelm','jyaelb','jyaels','jyaelt','jyaelp','jyaelh','jyaem','jyaeb','jyaebs','jyaes','jyaess','jyaeng','jyaej','jyaech','jyaek','jyaet','jyaep','jyaeh')


b=('Wan','Guo','Lu','Hao','Jie','Yi','Chou','Ju','Ju','Cheng','Zuo','Liang','Qiang','Zhi','Chui','Ya','Ju','Bei','Jiao','Zhuo','Zi','Bin','Peng','Ding','Chu','Chang','Men','Hua','Jian','Gui','Xi','Du','Qian','Dao','Gui','Dian','Luo','Zhi','Quan','Ming','Fu','Geng','Peng','Shan','Yi','Tuo','Sen','Duo','Ye','Fu','Wei','Wei','Duan','Jia','Zong','Jian','Yi','Shen','Xi','Yan','Yan','Chuan','Jian','Chun','Yu','He','Zha','Wo','Pian','Bi','Yao','Huo','Xu','Ruo','Yang','La','Yan','Ben','Hui','Kui','Jie','Kui','Si','Feng','Xie','Tuo','Zhi','Jian','Mu','Mao','Chu','Hu','Hu','Lian','Leng','Ting','Nan','Yu','You','Mei','Song','Xuan','Xuan','Yang','Zhen','Pian','Ye','Ji','Jie','Ye','Chu','Dun','Yu','Zou','Wei','Mei','Ti','Ji','Jie','Kai','Qiu','Ying','Rou','Huang','Lou','Le','Quan','Xiang','Pin','Shi','Gai','Tan','Lan','Wen','Yu','Chen','Lu','Ju','Shen','Chu','Bi','Xie','Jia','Yi','Zhan','Fu','Nuo','Mi','Lang','Rong','Gu','Jian','Ju','Ta','Yao','Zhen','Bang','Sha','Yuan','Zi','Ming','Su','Jia','Yao','Jie','Huang','Gan','Fei','Zha','Qian','Ma','Sun','Yuan','Xie','Rong','Shi','Zhi','Cui','Wen','Ting','Liu','Rong','Tang','Que','Zhai','Si','Sheng','Ta','Ke','Xi','Gu','Qi','Gao','Gao','Sun','Pan','Tao','Ge','Chun','Dian','Nou','Ji','Shuo','Gou','Chui','Qiang','Cha','Qian','Huai','Mei','Xu','Gang','Gao','Zhuo','Tuo','Qiao','Yang','Dian','Jia','Kan','Zui','Dao','Long','Bin','Zhu','Sang','Xi','Ji','Lian','Hui','Yong','Qian','Guo','Gai','Gai','Tuan','Hua','Qi','Sen','Cui','Peng','You','Hu','Jiang','Hu','Huan','Gui','Nie','Yi','Gao','Kang','Gui','Gui','Cao','Man','Jin')


b=('sseum','sseub','sseubs','sseus','sseuss','sseung','sseuj','sseuch','sseuk','sseut','sseup','sseuh','ssui','ssuig','ssuikk','ssuigs','ssuin','ssuinj','ssuinh','ssuid','ssuil','ssuilg','ssuilm','ssuilb','ssuils','ssuilt','ssuilp','ssuilh','ssuim','ssuib','ssuibs','ssuis','ssuiss','ssuing','ssuij','ssuich','ssuik','ssuit','ssuip','ssuih','ssi','ssig','ssikk','ssigs','ssin','ssinj','ssinh','ssid','ssil','ssilg','ssilm','ssilb','ssils','ssilt','ssilp','ssilh','ssim','ssib','ssibs','ssis','ssiss','ssing','ssij','ssich','ssik','ssit','ssip','ssih','a','ag','akk','ags','an','anj','anh','ad','al','alg','alm','alb','als','alt','alp','alh','am','ab','abs','as','ass','ang','aj','ach','ak','at','ap','ah','ae','aeg','aekk','aegs','aen','aenj','aenh','aed','ael','aelg','aelm','aelb','aels','aelt','aelp','aelh','aem','aeb','aebs','aes','aess','aeng','aej','aech','aek','aet','aep','aeh','ya','yag','yakk','yags','yan','yanj','yanh','yad','yal','yalg','yalm','yalb','yals','yalt','yalp','yalh','yam','yab','yabs','yas','yass','yang','yaj','yach','yak','yat','yap','yah','yae','yaeg','yaekk','yaegs','yaen','yaenj','yaenh','yaed','yael','yaelg','yaelm','yaelb','yaels','yaelt','yaelp','yaelh','yaem','yaeb','yaebs','yaes','yaess','yaeng','yaej','yaech','yaek','yaet','yaep','yaeh','eo','eog','eokk','eogs','eon','eonj','eonh','eod','eol','eolg','eolm','eolb','eols','eolt','eolp','eolh','eom','eob','eobs','eos','eoss','eong','eoj','eoch','eok','eot','eop','eoh','e','eg','ekk','egs','en','enj','enh','ed','el','elg','elm','elb','els','elt','elp','elh','em','eb','ebs','es','ess','eng','ej','ech','ek','et','ep','eh','yeo','yeog','yeokk','yeogs','yeon','yeonj','yeonh','yeod','yeol','yeolg','yeolm','yeolb','yeols','yeolt','yeolp','yeolh','yeom','yeob','yeobs','yeos')


b=('Yao','Yu','Chong','Xi','Xi','Jiu','Yu','Yu','Xing','Ju','Jiu','Xin','She','She','She','Jiu','Shi','Tan','Shu','Shi','Tian','Tan','Pu','Pu','Guan','Hua','Tian','Chuan','Shun','Xia','Wu','Zhou','Dao','Chuan','Shan','Yi','Fan','Pa','Tai','Fan','Ban','Chuan','Hang','Fang','Ban','Bi','Lu','Zhong','Jian','Cang','Ling','Zhu','Ze','Duo','Bo','Xian','Ge','Chuan','Xia','Lu','Qiong','Pang','Xi','Kua','Fu','Zao','Feng','Li','Shao','Yu','Lang','Ting','Yu','Wei','Bo','Meng','Nian','Ju','Huang','Shou','Ke','Bian','Mu','Die','Dao','Bang','Cha','Yi','Sou','Cang','Cao','Lou','Dai','Xue','Yao','Chong','Deng','Dang','Qiang','Lu','Yi','Ji','Jian','Huo','Meng','Qi','Lu','Lu','Chan','Shuang','Gen','Liang','Jian','Jian','Se','Yan','Fu','Ping','Yan','Yan','Cao','Cao','Yi','Le','Ting','Jiao','Ai','Nai','Tiao','Jiao','Jie','Peng','Wan','Yi','Chai','Mian','Mi','Gan','Qian','Yu','Yu','Shao','Qiong','Du','Hu','Qi','Mang','Zi','Hui','Sui','Zhi','Xiang','Pi','Fu','Tun','Wei','Wu','Zhi','Qi','Shan','Wen','Qian','Ren','Fu','Kou','Jie','Lu','Xu','Ji','Qin','Qi','Yan','Fen','Ba','Rui','Xin','Ji','Hua','Hua','Fang','Wu','Jue','Gou','Zhi','Yun','Qin','Ao','Chu','Mao','Ya','Fei','Reng','Hang','Cong','Yin','You','Bian','Yi','Qie','Wei','Li','Pi','E','Xian','Chang','Cang','Zhu','Su','Ti','Yuan','Ran','Ling','Tai','Shao','Di','Miao','Qing','Li','Yong','Ke','Mu','Bei','Bao','Gou','Min','Yi','Yi','Ju','Pie','Ruo','Ku','Ning','Ni','Bo','Bing','Shan','Xiu','Yao','Xian','Ben','Hong','Ying','Zha','Dong','Ju','Die','Nie','Gan','Hu','Ping','Mei','Fu','Sheng','Gu','Bi','Wei')


b=('Lang','Kan','Lao','Lai','Xian','Que','Kong','Chong','Chong','Ta','Lin','Hua','Ju','Lai','Qi','Min','Kun','Kun','Zu','Gu','Cui','Ya','Ya','Gang','Lun','Lun','Leng','Jue','Duo','Zheng','Guo','Yin','Dong','Han','Zheng','Wei','Xiao','Pi','Yan','Song','Jie','Beng','Zu','Ku','Dong','Zhan','Gu','Yin','Zi','Ze','Huang','Yu','Wai','Yang','Feng','Qiu','Yang','Ti','Yi','Zhi','Shi','Zai','Yao','E','Zhu','Kan','Lu','Yan','Mei','Han','Ji','Ji','Huan','Ting','Sheng','Mei','Qian','Wu','Yu','Zong','Lan','Ke','Yan','Yan','Wei','Zong','Cha','Sui','Rong','Ke','Qin','Yu','Qi','Lou','Tu','Dui','Xi','Weng','Cang','Dang','Rong','Jie','Kai','Liu','Wu','Song','Qiao','Zi','Wei','Beng','Dian','Cuo','Qian','Yong','Nie','Cuo','Ji','Shi','Ruo','Song','Zong','Jiang','Liao','Kang','Chan','Die','Cen','Ding','Tu','Lou','Zhang','Zhan','Zhan','Ao','Cao','Qu','Qiang','Cui','Zui','Dao','Dao','Xi','Yu','Pei','Long','Xiang','Ceng','Bo','Qin','Jiao','Yan','Lao','Zhan','Lin','Liao','Liao','Jin','Deng','Duo','Zun','Jiao','Gui','Yao','Jiao','Yao','Jue','Zhan','Yi','Xue','Nao','Ye','Ye','Yi','Nie','Xian','Ji','Xie','Ke','Xi','Di','Ao','Zui','Wei','Yi','Rong','Dao','Ling','Jie','Yu','Yue','Yin','Ru','Jie','Li','Gui','Long','Long','Dian','Rong','Xi','Ju','Chan','Ying','Kui','Yan','Wei','Nao','Quan','Chao','Cuan','Luan','Dian','Dian','Nie','Yan','Yan','Yan','Kui','Yan','Chuan','Kuai','Chuan','Zhou','Huang','Jing','Xun','Chao','Chao','Lie','Gong','Zuo','Qiao','Ju','Gong','Ju','Wu','Pu','Pu','Cha','Qiu','Qiu','Ji','Yi','Si','Ba','Zhi','Zhao','Xiang','Yi','Jin','Xun','Juan','Ba','Xun','Jin','Fu')


b=('Er','Gong','Ju','Jiao','Guang','He','Kai','Quan','Zhou','Zai','Zhi','She','Liang','Yu','Shao','You','Wan','Yin','Zhe','Wan','Fu','Qing','Zhou','Ni','Leng','Zhe','Zhan','Liang','Zi','Hui','Wang','Chuo','Guo','Kan','Yi','Peng','Qian','Gun','Nian','Ping','Guan','Bei','Lun','Pai','Liang','Ruan','Rou','Ji','Yang','Xian','Chuan','Cou','Chun','Ge','You','Hong','Shu','Fu','Zi','Fu','Wen','Ben','Zhan','Yu','Wen','Tao','Gu','Zhen','Xia','Yuan','Lu','Jiao','Chao','Zhuan','Wei','Hun','Xue','Zhe','Jiao','Zhan','Bu','Lao','Fen','Fan','Lin','Ge','Se','Kan','Huan','Yi','Ji','Zhui','Er','Yu','Jian','Hong','Lei','Pei','Li','Li','Lu','Lin','Che','Ya','Gui','Xuan','Dai','Ren','Zhuan','E','Lun','Ruan','Hong','Gu','Ke','Lu','Zhou','Zhi','Yi','Hu','Zhen','Li','Yao','Qing','Shi','Zai','Zhi','Jiao','Zhou','Quan','Lu','Jiao','Zhe','Fu','Liang','Nian','Bei','Hui','Gun','Wang','Liang','Chuo','Zi','Cou','Fu','Ji','Wen','Shu','Pei','Yuan','Xia','Nian','Lu','Zhe','Lin','Xin','Gu','Ci','Ci','Pi','Zui','Bian','La','La','Ci','Xue','Ban','Bian','Bian','Bian','Xue','Bian','Ban','Ci','Bian','Bian','Chen','Ru','Nong','Nong','Chan','Chuo','Chuo','Yi','Reng','Bian','Bian','Shi','Yu','Liao','Da','Chan','Gan','Qian','Yu','Yu','Qi','Xun','Yi','Guo','Mai','Qi','Za','Wang','Tu','Zhun','Ying','Da','Yun','Jin','Hang','Ya','Fan','Wu','Da','E','Hai','Zhe','Da','Jin','Yuan','Wei','Lian','Chi','Che','Ni','Tiao','Zhi','Yi','Jiong','Jia','Chen','Dai','Er','Di','Po','Zhu','Die','Ze','Tao','Shu','Tuo','Qu','Jing','Hui','Dong','You','Mi','Beng','Ji','Nai','Yi','Jie','Zhui','Lie','Xun')


b=('San','Lun','Ping','Zhao','Han','Yu','Dai','Zhao','Fei','Sha','Ling','Ta','Qu','Mang','Ye','Bao','Gui','Gua','Nan','Ge','Gaa','Shi','Ke','Suo','Ci','Zhou','Tai','Kuai','Qin','Xu','Du','Ce','Huan','Cong','Sai','Zheng','Qian','Jin','Zong','Wei','','','Xi','Na','Pu','Sou','Ju','Zhen','Shao','Tao','Ban','Ta','Qian','Weng','Rong','Luo','Hu','Sou','Zhong','Pu','Mie','Jin','Shao','Mi','Shu','Ling','Lei','Jiang','Leng','Zhi','Diao','','San','Gu','Fan','Mei','Sui','Jian','Tang','Xie','Ku','Wu','Fan','Luo','Can','Ceng','Ling','Yi','Cong','Yun','Meng','Yu','Zhi','Yi','Dan','Huo','Wei','Tan','Se','Xie','Sou','Song','Qian','Liu','Yi','Aau','Lei','Li','Fei','Lie','Lin','Xian','Xiao','Ou','Mi','Xian','Rang','Zhuan','Shuang','Yan','Bian','Ling','Hong','Qi','Liao','Ban','Bi','Hu','Hu','Caap','Ce','Pei','Qiong','Ming','Jiu','Bu','Mei','San','Wei','Zong','Bei','Li','Quan','Sam','Hun','Xiang','Zing','Shi','Ying','Gin','Nan','Huang','Jiu','Yan','Deoi','Sa','Tuan','Xie','Zhe','Men','Xi','Man','Zoeng','Huang','Tan','Xiao','Ye','Bi','Luo','Fan','Li','Cui','Chua','Dao','Di','Kuang','Chu','Xian','Chan','Mi','Qian','Qiu','Zhen','Zi','Heoi','Cim','Hu','Gan','Chi','Guai','Mu','Bo','Hua','Geng','Yao','Mao','Wang','','','','Ru','Xue','Zheng','Min','Jiang','O','Zhan','Zuo','Yue','Lie','Nou','Zhou','Bi','Ren','Yu','Gin','Chuo','Er','Yi','Mi','Qing','Zing','Wang','Ji','Bu','Syu','Bie','Fan','Yue','Li','Fan','Qu','Fu','Er','E','Zheng','Tian','Yu','Jin','Qi','Ju','Lai','Che','Bei','Niu','Yi','Xu','Mou','Xun','Fu','Cau','Nin','Ting','Beng','Zha','Wei')


b=('Ze','Shai','Gui','Yi','Hu','Chan','Kou','Cu','Ping','Zao','Ji','Gui','Su','Lou','Ce','Lu','Nian','Suo','Cuan','Diao','Suo','Le','Duan','Liang','Xiao','Bo','Mi','Shai','Dang','Liao','Dan','Dian','Fu','Jian','Min','Kui','Dai','Jiao','Deng','Huang','Sun','Lao','Zan','Xiao','Lu','Shi','Zan','Qi','Pai','Qi','Pai','Gan','Ju','Lu','Lu','Yan','Bo','Dang','Sai','Zhua','Gou','Qian','Lian','Bu','Zhou','Lai','Shi','Lan','Kui','Yu','Yue','Hao','Zhen','Tai','Ti','Nie','Chou','Ji','Yi','Qi','Teng','Zhuan','Zhou','Fan','Sou','Zhou','Qian','Zhuo','Teng','Lu','Lu','Jian','Tuo','Ying','Yu','Lai','Long','Qie','Lian','Lan','Qian','Yue','Zhong','Qu','Lian','Bian','Duan','Zuan','Li','Si','Luo','Ying','Yue','Zhuo','Yu','Mi','Di','Fan','Shen','Zhe','Shen','Nu','He','Lei','Xian','Zi','Ni','Cun','Zhang','Qian','Zhai','Bi','Ban','Wu','Sha','Kang','Rou','Fen','Bi','Cui','Yin','Zhe','Mi','Tai','Hu','Ba','Li','Gan','Ju','Po','Mo','Cu','Zhan','Zhou','Chi','Su','Tiao','Li','Xi','Su','Hong','Tong','Zi','Ce','Yue','Zhou','Lin','Zhuang','Bai','Lao','Fen','Er','Qu','He','Liang','Xian','Fu','Liang','Can','Jing','Li','Yue','Lu','Ju','Qi','Cui','Bai','Zhang','Lin','Zong','Jing','Guo','Hua','San','San','Tang','Bian','Rou','Mian','Hou','Xu','Zong','Hu','Jian','Zan','Ci','Li','Xie','Fu','Nuo','Bei','Gu','Xiu','Gao','Tang','Qiu','Jia','Cao','Zhuang','Tang','Mi','San','Fen','Zao','Kang','Jiang','Mo','San','San','Nuo','Xi','Liang','Jiang','Kuai','Bo','Huan','Shu','Zong','Xian','Nuo','Tuan','Nie','Li','Zuo','Di','Nie','Tiao','Lan','Mi','Si','Jiu','Xi','Gong','Zheng','Jiu','You')


b=('Hu','Ye','Ding','Qing','Kui','Xiang','Shun','Han','Xu','Yi','Xu','E','Song','Kui','Qi','Hang','Yu','Wan','Ban','Dun','Di','Dan','Pan','Po','Ling','Che','Jing','Lei','He','Qiao','E','E','Wei','Xie','Kuo','Shen','Yi','Yi','Hai','Dui','Yu','Ping','Lei','Fu','Jia','Tou','Hui','Kui','Jia','Luo','Ting','Cheng','Ying','Yun','Hu','Han','Jing','Tui','Tui','Pin','Lai','Tui','Zi','Zi','Chui','Ding','Lai','Tan','Han','Qian','Ke','Cui','Xuan','Qin','Yi','Sai','Ti','E','E','Yan','Wen','Kan','Yong','Zhuan','Yan','Xian','Xin','Yi','Yuan','Sang','Dian','Dian','Jiang','Kui','Lei','Lao','Piao','Wai','Man','Cu','Yao','Hao','Qiao','Gu','Xun','Yan','Hui','Chan','Ru','Meng','Bin','Xian','Pin','Lu','Lan','Nie','Quan','Ye','Ding','Qing','Han','Xiang','Shun','Xu','Xu','Wan','Gu','Dun','Qi','Ban','Song','Hang','Yu','Lu','Ling','Po','Jing','Jie','Jia','Ting','He','Ying','Jiong','Ke','Yi','Pin','Hui','Tui','Han','Ying','Ying','Ke','Ti','Yong','E','Zhuan','Yan','E','Nie','Man','Dian','Sang','Hao','Lei','Chan','Ru','Pin','Quan','Feng','Biao','Gua','Fu','Xia','Zhan','Biao','Sa','Ba','Tai','Lie','Gua','Xuan','Shao','Ju','Biao','Si','Wei','Yang','Yao','Sou','Kai','Sou','Fan','Liu','Xi','Liu','Piao','Piao','Liu','Biao','Biao','Biao','Liao','Biao','Se','Feng','Xiu','Feng','Yang','Zhan','Biao','Sa','Ju','Si','Sou','Yao','Liu','Piao','Biao','Biao','Fei','Fan','Fei','Fei','Shi','Shi','Can','Ji','Ding','Si','Tuo','Zhan','Sun','Xiang','Tun','Ren','Yu','Juan','Chi','Yin','Fan','Fan','Sun','Yin','Tou','Yi','Zuo','Bi','Jie','Tao','Bao','Ci','Tie','Si','Bao','Shi','Duo')


b=('Chang','Zhi','Bing','Jiu','Yao','Cui','Lia','Wan','Lai','Cang','Zong','Ge','Guan','Bei','Tian','Shu','Shu','Men','Dao','Tan','Jue','Chui','Xing','Peng','Tang','Hou','Yi','Qi','Ti','Gan','Jing','Jie','Sui','Chang','Jie','Fang','Zhi','Kong','Juan','Zong','Ju','Qian','Ni','Lun','Zhuo','Wo','Luo','Song','Leng','Hun','Dong','Zi','Ben','Wu','Ju','Nai','Cai','Jian','Zhai','Ye','Zhi','Sha','Qing','Ning','Ying','Cheng','Qian','Yan','Ruan','Zhong','Chun','Jia','Ji','Wei','Yu','Bing','Ruo','Ti','Wei','Pian','Yan','Feng','Tang','Wo','E','Xie','Che','Sheng','Kan','Di','Zuo','Cha','Ting','Bei','Xie','Huang','Yao','Zhan','Chou','Yan','You','Jian','Xu','Zha','Ci','Fu','Bi','Zhi','Zong','Mian','Ji','Yi','Xie','Xun','Cai','Duan','Ce','Zhen','Ou','Tou','Tou','Bei','Za','Lou','Jie','Wei','Fen','Chang','Gui','Sou','Zhi','Su','Xia','Fu','Yuan','Rong','Li','Nu','Yun','Jiang','Ma','Bang','Dian','Tang','Hao','Jie','Xi','Shan','Qian','Jue','Cang','Chu','San','Bei','Xiao','Yong','Yao','Tan','Suo','Yang','Fa','Bing','Jia','Dai','Zai','Tang','Gu','Bin','Chu','Nuo','Can','Lei','Cui','Yong','Zao','Zong','Beng','Song','Ao','Chuan','Yu','Zhai','Zu','Shang','Chuang','Jing','Chi','Sha','Han','Zhang','Qing','Yan','Di','Xie','Lou','Bei','Piao','Jin','Lian','Lu','Man','Qian','Xian','Tan','Ying','Dong','Zhuan','Xiang','Shan','Qiao','Jiong','Tui','Zun','Pu','Xi','Lao','Chang','Guang','Liao','Qi','Cheng','Chan','Wei','Ji','Bo','Hui','Chuan','Tie','Dan','Jiao','Jiu','Seng','Fen','Xian','Ju','E','Jiao','Jian','Tong','Lin','Bo','Gu','Xian','Su','Xian','Jiang','Min','Ye','Jin','Jia','Qiao','Pi','Feng','Zhou','Ai','Sai')


b=('Han','Xuan','Yan','Qiu','Xuan','Lang','Li','Xiu','Fu','Liu','Ya','Xi','Ling','Li','Jin','Lian','Suo','Suo','Feng','Wan','Dian','Pin','Zhan','Se','Min','Yu','Ju','Chen','Lai','Min','Sheng','Wei','Tian','Chu','Zuo','Beng','Cheng','Hu','Qi','E','Kun','Chang','Qi','Beng','Wan','Lu','Cong','Guan','Yan','Diao','Bei','Lin','Qin','Pi','Pa','Que','Zhuo','Qin','Fa','Jin','Qiong','Du','Jie','Hun','Yu','Mao','Mei','Chun','Xuan','Ti','Xing','Dai','Rou','Min','Jian','Wei','Ruan','Huan','Xie','Chuan','Jian','Zhuan','Chang','Lian','Quan','Xia','Duan','Yuan','Ya','Nao','Hu','Ying','Yu','Huang','Rui','Se','Liu','Shi','Rong','Suo','Yao','Wen','Wu','Zhen','Jin','Ying','Ma','Tao','Liu','Tang','Li','Lang','Gui','Zhen','Qiang','Cuo','Jue','Zhao','Yao','Ai','Bin','Shu','Chang','Kun','Zhuan','Cong','Jin','Yi','Cui','Cong','Qi','Li','Jing','Suo','Qiu','Xuan','Ao','Lian','Men','Zhang','Yin','Ye','Ying','Wei','Lu','Wu','Deng','Xiu','Zeng','Xun','Qu','Dang','Lin','Liao','Qiong','Su','Huang','Gui','Pu','Jing','Fan','Jin','Liu','Ji','Hui','Jing','Ai','Bi','Can','Qu','Zao','Dang','Jiao','Gun','Tan','Hui','Huan','Se','Sui','Tian','Chu','Yu','Jin','Lu','Bin','Shu','Wen','Zui','Lan','Xi','Zi','Xuan','Ruan','Wo','Gai','Lei','Du','Li','Zhi','Rou','Li','Zan','Qiong','Ti','Gui','Sui','La','Long','Lu','Li','Zan','Lan','Ying','Mi','Xiang','Qiong','Guan','Dao','Zan','Huan','Gua','Bo','Die','Bo','Hu','Zhi','Piao','Ban','Rang','Li','Wa','Ngaa','Xiang','Qian','Ban','Pen','Fang','Dan','Weng','Ou','Fan','Hou','Wa','Hu','Ling','Yi','Ping','Ci','Bai','Juan','Chang','Chi','Sarake','Dang','Meng','Bu')


b=('Ba','Fang','Chen','Xing','Dou','Yue','Qian','Fu','Pi','Na','Xin','E','Jue','Dun','Gou','Yin','Qian','Ban','Sa','Ren','Chao','Niu','Fen','Yun','Yi','Qin','Pi','Guo','Hong','Yin','Jun','Diao','Yi','Zhong','Xi','Gai','Ri','Huo','Tai','Kang','Yuan','Lu','E','Qin','Duo','Zi','Ni','Tu','Shi','Min','Gu','Ke','Ling','Bing','Si','Gu','Bo','Pi','Yu','Si','Zuo','Bu','You','Tian','Jia','Zhen','Shi','Shi','Zhi','Ju','Chan','Shi','Shi','Xuan','Zhao','Bao','He','Bi','Sheng','Chu','Shi','Bo','Zhu','Chi','Za','Po','Tong','Qian','Fu','Zhai','Liu','Qian','Fu','Li','Yue','Pi','Yang','Ban','Bo','Jie','Gou','Shu','Zheng','Mu','Xi','Xi','Di','Jia','Mu','Tan','Huan','Yi','Si','Kuang','Ka','Bei','Jian','Tong','Xing','Hong','Jiao','Chi','Er','Luo','Bing','Shi','Mou','Jia','Yin','Jun','Zhou','Chong','Xiang','Tong','Mo','Lei','Ji','Yu','Xu','Ren','Zun','Zhi','Qiong','Shan','Chi','Xian','Xing','Quan','Pi','Tie','Zhu','Xiang','Ming','Kua','Yao','Xian','Xian','Xiu','Jun','Cha','Lao','Ji','Pi','Ru','Mi','Yi','Yin','Guang','An','Diu','You','Se','Kao','Qian','Luan','Si','Ai','Diao','Han','Rui','Shi','Keng','Qiu','Xiao','Zhe','Xiu','Zang','Ti','Cuo','Gua','Hong','Zhong','Tou','Lu','Mei','Lang','Wan','Xin','Yun','Bei','Wu','Su','Yu','Chan','Ding','Bo','Han','Jia','Hong','Cuan','Feng','Chan','Wan','Zhi','Si','Xuan','Hua','Yu','Tiao','Kuang','Zhuo','Lue','Xing','Qin','Shen','Han','Lue','Ye','Chu','Zeng','Ju','Xian','Tie','Mang','Pu','Li','Pan','Rui','Cheng','Gao','Li','Te','Bing','Zhu','Zhen','Tu','Liu','Zui','Ju','Chang','Yuan','Jian','Gang','Diao','Tao','Chang')


b=('Yi','Jun','Nong','Chan','Yi','Dang','Jing','Xuan','Kuai','Jian','Chu','Dan','Jiao','Sha','Zai','Can','Bin','An','Ru','Tai','Chou','Chai','Lan','Ni','Jin','Qian','Meng','Wu','Ning','Qiong','Ni','Chang','Lie','Lei','Lu','Kuang','Bao','Yu','Biao','Zan','Zhi','Si','You','Hao','Qing','Chen','Li','Teng','Wei','Long','Chu','Chan','Rang','Shu','Hui','Li','Luo','Zan','Nuo','Tang','Yan','Lei','Nang','Er','Wu','Yun','Zan','Yuan','Xiong','Chong','Zhao','Xiong','Xian','Guang','Dui','Ke','Dui','Mian','Tu','Chang','Er','Dui','Er','Jin','Tu','Si','Yan','Yan','Shi','Shi ','Dang','Qian','Dou','Fen','Mao','Shen','Dou','Bai ','Jing','Li','Huang','Ru','Wang','Nei','Quan','Liang','Yu','Ba','Gong','Liu','Xi','Han','Lan','Gong','Tian','Guan','Xing','Bing','Qi','Ju','Dian','Zi','Fen','Yang','Jian','Shou','Ji','Yi','Ji','Chan','Jiong','Mao','Ran','Nei','Yuan','Mao','Gang','Ran','Ce','Jiong','Ce','Zai','Gua','Jiong','Mao','Zhou','Mao','Gou','Xu','Mian','Mi','Rong','Yin','Xie','Kan','Jun','Nong','Yi','Mi','Shi','Guan','Meng','Zhong','Ju','Yuan','Ming','Kou','Lin','Fu','Xie','Mi','Bing','Dong','Tai','Gang','Feng','Bing','Hu','Chong','Jue','Hu','Kuang','Ye','Leng','Pan','Fu','Min','Dong','Xian','Lie','Qia','Jian','Jing','Sou','Mei','Tu','Qi','Gu','Zhun','Song','Jing','Liang','Qing','Diao','Ling','Dong','Gan','Jian','Yin','Cou','Ai','Li','Chuang','Ming','Zhun','Cui','Si','Duo','Jin','Lin','Lin','Ning','Xi','Du','Ji','Fan','Fan','Fan','Feng','Ju','Chu','Zheng','Feng','Mu','Zhi','Fu','Feng','Ping','Feng','Kai','Huang','Kai','Gan','Deng','Ping','Qian','Xiong','Kuai','Tu','Ao','Chu','Ji','Dang','Han','Han','Zao')


b=('sswals','sswalt','sswalp','sswalh','sswam','sswab','sswabs','sswas','sswass','sswang','sswaj','sswach','sswak','sswat','sswap','sswah','sswae','sswaeg','sswaekk','sswaegs','sswaen','sswaenj','sswaenh','sswaed','sswael','sswaelg','sswaelm','sswaelb','sswaels','sswaelt','sswaelp','sswaelh','sswaem','sswaeb','sswaebs','sswaes','sswaess','sswaeng','sswaej','sswaech','sswaek','sswaet','sswaep','sswaeh','ssoe','ssoeg','ssoekk','ssoegs','ssoen','ssoenj','ssoenh','ssoed','ssoel','ssoelg','ssoelm','ssoelb','ssoels','ssoelt','ssoelp','ssoelh','ssoem','ssoeb','ssoebs','ssoes','ssoess','ssoeng','ssoej','ssoech','ssoek','ssoet','ssoep','ssoeh','ssyo','ssyog','ssyokk','ssyogs','ssyon','ssyonj','ssyonh','ssyod','ssyol','ssyolg','ssyolm','ssyolb','ssyols','ssyolt','ssyolp','ssyolh','ssyom','ssyob','ssyobs','ssyos','ssyoss','ssyong','ssyoj','ssyoch','ssyok','ssyot','ssyop','ssyoh','ssu','ssug','ssukk','ssugs','ssun','ssunj','ssunh','ssud','ssul','ssulg','ssulm','ssulb','ssuls','ssult','ssulp','ssulh','ssum','ssub','ssubs','ssus','ssuss','ssung','ssuj','ssuch','ssuk','ssut','ssup','ssuh','sswo','sswog','sswokk','sswogs','sswon','sswonj','sswonh','sswod','sswol','sswolg','sswolm','sswolb','sswols','sswolt','sswolp','sswolh','sswom','sswob','sswobs','sswos','sswoss','sswong','sswoj','sswoch','sswok','sswot','sswop','sswoh','sswe','ssweg','sswekk','sswegs','sswen','sswenj','sswenh','sswed','sswel','sswelg','sswelm','sswelb','sswels','sswelt','sswelp','sswelh','sswem','ssweb','sswebs','sswes','sswess','ssweng','sswej','sswech','sswek','sswet','sswep','ssweh','sswi','sswig','sswikk','sswigs','sswin','sswinj','sswinh','sswid','sswil','sswilg','sswilm','sswilb','sswils','sswilt','sswilp','sswilh','sswim','sswib','sswibs','sswis','sswiss','sswing','sswij','sswich','sswik','sswit','sswip','sswih','ssyu','ssyug','ssyukk','ssyugs','ssyun','ssyunj','ssyunh','ssyud','ssyul','ssyulg','ssyulm','ssyulb','ssyuls','ssyult','ssyulp','ssyulh','ssyum','ssyub','ssyubs','ssyus','ssyuss','ssyung','ssyuj','ssyuch','ssyuk','ssyut','ssyup','ssyuh','sseu','sseug','sseukk','sseugs','sseun','sseunj','sseunh','sseud','sseul','sseulg','sseulm','sseulb','sseuls','sseult','sseulp','sseulh')


b=('Gui','Deng','Zhi','Xu','Yi','Hua','Xi','Kui','Rao','Xi','Yan','Chan','Jiao','Mei','Fan','Fan','Xian','Yi','Hui','Jiao','Fu','Shi','Bi','Shan','Sui','Qiang','Lian','Huan','Xin','Niao','Dong','Yi','Can','Ai','Niang','Ning','Ma','Tiao','Chou','Jin','Ci','Yu','Pin','Rong','Ru','Nai','Yan','Tai','Ying','Qian','Niao','Yue','Ying','Mian','Bi','Ma','Shen','Xing','Ni','Du','Liu','Yuan','Lan','Yan','Shuang','Ling','Jiao','Niang','Lan','Qian','Ying','Shuang','Hui','Quan','Mi','Li','Luan','Yan','Zhu','Lan','Zi','Jie','Jue','Jue','Kong','Yun','Ma','Zi','Cun','Sun','Fu','Bei','Zi','Xiao','Xin','Meng','Si','Tai','Bao','Ji','Gu','Nu','Xue','You','Zhuan','Hai','Luan','Sun','Nao','Mie','Cong','Qian','Shu','Can','Ya','Zi','Ni','Fu','Zi','Li','Xue','Bo','Ru','Nai','Nie','Nie','Ying','Luan','Mian','Ning','Rong','Ta','Gui','Zhai','Qiong','Yu','Shou','An','Tu','Song','Wan','Rou','Yao','Hong','Yi','Jing','Zhun','Mi','Zhu','Dang','Hong','Zong','Guan','Zhou','Ding','Wan','Yi','Bao','Shi','Shi','Chong','Shen','Ke','Xuan','Shi','You','Huan','Yi','Tiao','Shi','Xian','Gong','Cheng','Qun','Gong','Xiao','Zai','Zha','Bao','Hai','Yan','Xiao','Jia','Shen','Chen','Rong','Huang','Mi','Kou','Kuan','Bin','Su','Cai','Zan','Ji','Yuan','Ji','Yin','Mi','Kou','Qing','He','Zhen','Jian','Fu','Ning','Bing','Huan','Mei','Qin','Han','Yu','Shi','Ning','Jin','Ning','Zhi','Yu','Bao','Kuan','Ning','Qin','Mo','Cha','Ju','Gua','Qin','Hu','Wu','Liao','Shi','Ning','Zhai','Shen','Wei','Xie','Kuan','Hui','Liao','Jun','Huan','Yi','Yi','Bao','Qin','Chong','Bao','Feng','Cun','Dui','Si','Xun','Dao','Lu','Dui','Shou')